%
% bsim_collcrossconddata2.m
%
% Batch simulation script that collects data across dopamine conditions in 
% and all pathway choices for manipulation (NS = Nod/Shake, B = Babble, 
% PR = Plan/Request, g = global (all paths)).  This doesn't show the
% graphs, though.
%
% Last modification: 2/8/08


% Set path stuff.
runcoll_path = runcoll_stats;
taskset_path = taskset_TOBS1c_TOBS1crev;
% simphases_path = simphases_maint;
% simphases_path = simphases_train;
simphases_path = simphases_rev;

num_pathmanips = 4;
num_conds = 10;
num_train_subjs = 10;
num_maint_subjs = 5;
num_rev_subjs = 10;
if (simphases_path == simphases_train)
    num_subjs = num_train_subjs;
elseif (simphases_path == simphases_maint)
    num_subjs = num_maint_subjs;
elseif (simphases_path == simphases_rev)  
    num_subjs = num_rev_subjs;
end;

mean_RTs = zeros(num_conds,num_subjs,num_pathmanips);
mean_rew_to_next_resps = zeros(num_conds,num_subjs,num_pathmanips);
ave_pct_corrects = zeros(num_conds,num_subjs,num_pathmanips);
ave_pct_incorrect = zeros(num_conds,num_subjs,num_pathmanips);
ave_pct_missed = zeros(num_conds,num_subjs,num_pathmanips);
ave_pct_conflict = zeros(num_conds,num_subjs,num_pathmanips);
ave_pct_extra_resp = zeros(num_conds,num_subjs,num_pathmanips);
ave_pct_late = zeros(num_conds,num_subjs,num_pathmanips);
learn_trials_meas = zeros(num_conds,num_subjs,num_pathmanips);
end_accur_meas = zeros(num_conds,num_subjs,num_pathmanips);
end_incorr_meas = zeros(num_conds,num_subjs,num_pathmanips);
end_missed_meas = zeros(num_conds,num_subjs,num_pathmanips);
end_conflict_meas = zeros(num_conds,num_subjs,num_pathmanips);
end_extra_resp_meas = zeros(num_conds,num_subjs,num_pathmanips);
end_late_meas = zeros(num_conds,num_subjs,num_pathmanips);
conj_learned_meas = zeros(num_conds,num_subjs,num_pathmanips);
wrong_guess_first_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_babble_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_plan_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_nod_req_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_shake_req_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_babble_req_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);  
ave_nod_go_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_shake_go_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_babble_go_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_nod_nogo_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_shake_nogo_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);
ave_babble_nogo_activ_meas = zeros(num_conds,num_subjs,num_pathmanips);

% For each path manipulation...
for pathmanip_ind = 1:4
    % Set the manipulations list.
    if (pathmanip_ind == 1)
        manip_conds = [ manip_NShypo3 manip_NShypo2 manip_NShypo15 ...
            manip_NShypo1 manip_NShypo05 manip_normal manip_NShyper05 ...
            manip_NShyper1 manip_NShyper3 manip_NShyper5 ];
    elseif (pathmanip_ind == 2)
        manip_conds = [ manip_Bhypo3 manip_Bhypo2 manip_Bhypo15 ...
            manip_Bhypo1 manip_Bhypo05 manip_normal manip_Bhyper05 ...
            manip_Bhyper1 manip_Bhyper3 manip_Bhyper5 ];
    elseif (pathmanip_ind == 3)   
        manip_conds = [ manip_PRhypo3 manip_PRhypo2 manip_PRhypo15 ...
            manip_PRhypo1 manip_PRhypo05 manip_normal manip_PRhyper05 ...
            manip_PRhyper1 manip_PRhyper3 manip_PRhyper5 ];        
    elseif (pathmanip_ind == 4)
        manip_conds = [ manip_ghypo3 manip_ghypo2 manip_ghypo15 ...
            manip_ghypo1 manip_ghypo05 manip_normal manip_ghyper05 ...
            manip_ghyper1 manip_ghyper3 manip_ghyper5 ];            
    end;
    
    % For each DA condition...
    for cond_ind = 1:num_conds
        manip_path = manip_conds(cond_ind);
        
        % For each subject...
        for subj_ind = 1:num_subjs
            subj_num = subj_ind;  
            bsim_setdatapath;   
            bsim_loadmultirun;
            collect_perf_data;       
            mean_RTs(cond_ind,subj_ind,pathmanip_ind) = mean_RT;
            mean_rew_to_next_resps(cond_ind,subj_ind,pathmanip_ind) = ...
                mean_rew_to_next_resp;
            ave_pct_corrects(cond_ind,subj_ind,pathmanip_ind) = ...
                pct_correct;
            ave_pct_incorrect(cond_ind,subj_ind,pathmanip_ind) = ...
                pct_incorrect;
            ave_pct_missed(cond_ind,subj_ind,pathmanip_ind) = pct_missed; 
            ave_pct_conflict(cond_ind,subj_ind,pathmanip_ind) = ...
                pct_conflict;
            ave_pct_extra_resp(cond_ind,subj_ind,pathmanip_ind) = ...
                pct_extra_resp;
            ave_pct_late(cond_ind,subj_ind,pathmanip_ind) = pct_late;
            learn_trials_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                learn_trials;
            end_accur_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                last13pct_corr;
            end_incorr_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                last13pct_incorr;
            end_missed_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                last13pct_missed;
            end_conflict_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                last13pct_conflict;
            end_extra_resp_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                last13pct_extra_resp;
            end_late_meas(cond_ind,subj_ind,pathmanip_ind) = last13pct_late;
            conj_learned_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                conj_learned;
            wrong_guess_first_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                wrong_guess_first;
            ave_babble_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_babble_activ;
            ave_plan_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_plan_activ;
            ave_nod_req_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_nod_req_activ;
            ave_shake_req_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_shake_req_activ;
            ave_babble_req_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_babble_req_activ;
            ave_nod_go_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_nod_go_activ; 
            ave_shake_go_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_shake_go_activ; 
            ave_babble_go_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_babble_go_activ; 
            ave_nod_nogo_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_nod_nogo_activ; 
            ave_shake_nogo_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_shake_nogo_activ;
            ave_babble_nogo_activ_meas(cond_ind,subj_ind,pathmanip_ind) = ...
                ave_babble_nogo_activ;
        end;
    end;
end;

% Set collected data file.
fname = strcat(path_pfx1,path_pfx2,path_pfx3,path_pfx4,'colldata.mat');

% Save the collected data file.
save(fname,'mean_RTs','mean_rew_to_next_resps','ave_pct_corrects', ...
    'ave_pct_incorrect','ave_pct_missed','ave_pct_conflict', ...
    'ave_pct_extra_resp','ave_pct_late','learn_trials_meas', ...
    'end_accur_meas','end_incorr_meas','end_missed_meas', ...
    'end_conflict_meas','end_extra_resp_meas','end_late_meas', ...
    'conj_learned_meas','wrong_guess_first_meas','ave_babble_activ_meas', ...
    'ave_plan_activ_meas','ave_nod_req_activ_meas', ...
    'ave_shake_req_activ_meas','ave_babble_req_activ_meas', ...
    'ave_nod_go_activ_meas','ave_shake_go_activ_meas', ...
    'ave_babble_go_activ_meas','ave_nod_nogo_activ_meas', ...
    'ave_shake_nogo_activ_meas','ave_babble_nogo_activ_meas');