%
% bsim_mr_plot_trials.m
%
% Batch simulation script which plots (multirun) trial data.
%
% Last modification: 12/5/07


% Make sure we have all of the model indices.
% get_cog_model_indices;

% Set the boundary for the init units, so we can display them.
premotor_exec_thresh = 0.65;
babble_exec_thresh = 0.5;

%
% Set up user-selected initial variables.
%

% Choose the set of things to be plotted.
plot_set = 1;     % basic simulation (no cognitive model)
                  % stimuli, responses, and reinforcements
% plot_set = 2;   % C tone adaptive critic simulation (unused)
% plot_set = 3;   % general cognitive model simulation (unused)
% plot_set = 4;   % Nod gating plots
% plot_set = 5;   % Shake gating plots
% plot_set = 6;   % Babble gating plots
% plot_set = 7;   % Nod Request focus analysis plots
% plot_set = 8;   % Shake Request focus analysis plots
% plot_set = 9;   % Nod-Shake Conflict plots
% plot_set = 10;  % Babble Request focus analysis plots (not done yet)
% plot_set = 11;  % Nod Init focus analysis plots
% plot_set = 12;  % Shake Init focus analysis plots
% plot_set = 13;  % Babble Init focus analysis plots
% plot_set = 14;  % Adaptive Go/NoGo unit threshold plots
% plot_set = 15;  % DA Effect plots

% Set up range of trials to plot.
min_trial = 1;
max_trial = num_trials;

% Grab script arguments if they exist.
if (~isempty(who('ps_sargs')))
    nargs = size(ps_sargs,2);
    if (nargs > 0)
        plot_set = ps_sargs(1);
    end;
    if (nargs >= 3)
        min_trial = ps_sargs(2);
        max_trial = ps_sargs(3);
    end;
end;

% Initialize title of plot.
plot_title = 'Trial Plots';

% Lay out the display.
% ID#  What it plots
% -------------------
%   1  Color of stimulus (Red, Green, Blue, Yellow)
%   2  Tone stimulus context (Blue/C, Red/Eb)
%   3  Behavior execution (nothing/Track, Green/Nod, Red/Shake, Both/Black)
%   4  Errors (Green/Correct, Black/Miss, Red/Wrong Response, 
%        Yellow/Double Response, Blue/Extra Correct Response, 
%        Orangle/Delay Response, Violet/Blind Response
%   5  Reinforcement activation (Green/Reward, Red/Punisher)
%   6  Moving 3-pt. window of average percent correct
%   7  Moving 5-pt. window of average percent correct
%   8  Moving 7-pt. window of average percent correct
%   9  Moving 13-pt. window of average percent correct
%  10  Trial period color working memory unit activation
%  11  Trial stimulus period color working memory unit activation 
%  12  Trial delay period color working memory unit activation
%  13  Trial period tone working memory unit activation
%  14  Trial stimulus period tone working memory unit activation 
%  15  Trial delay period tone working memory unit activation
%  16  Trial period novelty unit activation
%  17  Trial stimulus period novelty unit activation 
%  18  Trial delay period novelty unit activation
%  19  Trial period DA unit activation
%  20  Trial stimulus period DA unit activation 
%  21  Trial delay period DA unit activation
%  22  Trial period frustration unit activation
%  23  Trial stimulus period frustration unit activation 
%  24  Trial delay period frustration unit activation
%  25  Trial period Babble Request unit activation
%  26  Trial stimulus period Babble Request unit activation 
%  27  Trial delay period Babble Request unit activation
%  28  Trial period Babble GoE sum activation
%  29  Trial stimulus period Babble GoE sum activation 
%  30  Trial delay period Babble GoE sum activation
%  31  Trial period Babble GoI sum activation
%  32  Trial stimulus period Babble GoI sum activation 
%  33  Trial delay period Babble GoI sum activation
%  34  Trial period Babble NoGo sum activation
%  35  Trial stimulus period Babble NoGo sum activation 
%  36  Trial delay period Babble NoGo sum activation
%  37  Trial period Babble Init unit activation
%  38  Trial stimulus period Babble Init unit activation 
%  39  Trial delay period Babble Init unit activation
%  40  Trial period Babble Exec unit activation
%  41  Trial stimulus period Babble Exec unit activation 
%  42  Trial delay period Babble Exec unit activation
%  43  Trial period Babble sum activation
%  44  Trial stimulus period Babble sum activation 
%  45  Trial delay period Babble sum activation
%  46  Trial period Plan sum activation
%  47  Trial stimulus period Plan sum activation 
%  48  Trial delay period Plan sum activation
%  49  Trial period Nod Request sum activation
%  50  Trial stimulus period Nod Request sum activation 
%  51  Trial delay period Nod Request sum activation
%  52  Trial period Nod GoE sum activation
%  53  Trial stimulus period Nod GoE sum activation 
%  54  Trial delay period Nod GoE sum activation
%  55  Trial period Nod GoI sum activation
%  56  Trial stimulus period Nod GoI sum activation 
%  57  Trial delay period Nod GoI sum activation
%  58  Trial period Nod NoGo sum activation
%  59  Trial stimulus period Nod NoGo sum activation 
%  60  Trial delay period Nod NoGo sum activation
%  61  Trial period Nod Init unit activation
%  62  Trial stimulus period Nod Init unit activation 
%  63  Trial delay period Nod Init unit activation
%  64  Trial period Shake Request sum activation
%  65  Trial stimulus period Shake Request sum activation 
%  66  Trial delay period Shake Request sum activation
%  67  Trial period Shake GoE sum activation
%  68  Trial stimulus period Shake GoE sum activation 
%  69  Trial delay period Shake GoE sum activation
%  70  Trial period Shake GoI sum activation
%  71  Trial stimulus period Shake GoI sum activation 
%  72  Trial delay period Shake GoI sum activation
%  73  Trial period Shake NoGo sum activation
%  74  Trial stimulus period Shake NoGo sum activation 
%  75  Trial delay period Shake NoGo sum activation
%  76  Trial period Shake Init unit activation
%  77  Trial stimulus period Shake Init unit activation 
%  78  Trial delay period Shake Init unit activation
%  79  Trial period N/S Conflict unit activation
%  80  Trial stimulus period N/S Conflict unit activation 
%  81  Trial delay period N/S Conflict unit activation

% This is the ordering in which the plots are to be shown...
switch(plot_set)
    case 1
        disp_plot_map = [ 1 2 3 4 5 9 25 28 34 37 40 ];
    case 2
        disp_plot_map = [ 1 2 3 4 5 6 ];
    case 3
        disp_plot_map = [ 1 2 3 4 5 6 ];
    case 4
        disp_plot_map = [ 1 2 43 46 49 52 55 58 61 3 4 5 9 ]; 
    case 5
        disp_plot_map = [ 1 2 43 46 64 67 70 73 76 3 4 5 9 ]; 
    case 6
        disp_plot_map = [ 1 2 16 22 25 28 31 34 37 40 43 3 4 5 9 ];        
end;

% Initialize labels for plots (in order of plot IDs).
plot_labels = ...
    str2mat( ...
    'default', ...  % Color of stimulus    
    'default', ...  % Tone stimulus context
    'default', ...  % Behavior execution  
    'default', ...  % Errors 
    'default', ...  % Reinforcement activation 
    'default', ...  % Moving 3-window percent correct 
    'default', ...  % Moving 5-window percent correct 
    'default', ...  % Moving 7-window percent correct
    'default', ...  % Moving 13-window percent correct   
    'default', ...  % Trial period color working memory unit activation 
    'default', ...  % Trial stimulus period color working memory unit activation 
    'default', ...  % Trial delay period color working memory unit activation  
    'default', ...  % Trial period tone working memory unit activation 
    'default', ...  % Trial stimulus period tone working memory unit activation 
    'default', ...  % Trial delay period tone working memory unit activation     
    'default', ...  % Trial period novelty unit activation 
    'default', ...  % Trial stimulus period novelty unit activation 
    'default', ...  % Trial delay period novelty unit activation   
    'default', ...  % Trial period DA unit activation 
    'default', ...  % Trial stimulus period DA unit activation 
    'default', ...  % Trial delay period DA unit activation     
    'default', ...  % Trial period frustration unit activation 
    'default', ...  % Trial stimulus period frustration unit activation 
    'default', ...  % Trial delay period frustration unit activation 
    'default', ...  % Trial period Babble Request unit activation 
    'default', ...  % Trial stimulus period Babble Request unit activation 
    'default', ...  % Trial delay period Babble Request unit activation   
    'default', ...  % Trial period Babble GoE sum activation 
    'default', ...  % Trial stimulus period Babble GoE sum activation 
    'default', ...  % Trial delay period Babble GoE sum activation
    'default', ...  % Trial period Babble GoI sum activation 
    'default', ...  % Trial stimulus period Babble GoI sum activation 
    'default', ...  % Trial delay period Babble GoI sum activation   
    'default', ...  % Trial period Babble NoGo sum activation 
    'default', ...  % Trial stimulus period Babble NoGo sum activation 
    'default', ...  % Trial delay period Babble NoGo sum activation  
    'default', ...  % Trial period Babble Init unit activation 
    'default', ...  % Trial stimulus period Babble Init unit activation 
    'default', ...  % Trial delay period Babble Init unit activation   
    'default', ...  % Trial period Babble Exec unit activation 
    'default', ...  % Trial stimulus period Babble Exec unit activation 
    'default', ...  % Trial delay period Babble Exec unit activation   
    'default', ...  % Trial period Babble sum activation 
    'default', ...  % Trial stimulus period Babble sum activation 
    'default', ...  % Trial delay period Babble activation   
    'default', ...  % Trial period Plan sum activation 
    'default', ...  % Trial stimulus period Plan sum activation 
    'default', ...  % Trial delay period Plan sum activation    
    'default', ...  % Trial period Nod Request sum activation 
    'default', ...  % Trial stimulus period Nod Request sum activation 
    'default', ...  % Trial delay period Nod Request sum activation 
    'default', ...  % Trial period Nod GoE sum activation 
    'default', ...  % Trial stimulus period Nod GoE sum activation 
    'default', ...  % Trial delay period Nod GoE sum activation  
    'default', ...  % Trial period Nod GoI sum activation 
    'default', ...  % Trial stimulus period Nod GoI sum activation 
    'default', ...  % Trial delay period Nod GoI sum activation
    'default', ...  % Trial period Nod NoGo sum activation 
    'default', ...  % Trial stimulus period Nod NoGo sum activation 
    'default', ...  % Trial delay period Nod NoGo sum activation  
    'default', ...  % Trial period Nod Init unit activation 
    'default', ...  % Trial stimulus period Nod Init unit activation 
    'default', ...  % Trial delay period Nod Init unit activation    
    'default', ...  % Trial period Shake Request sum activation 
    'default', ...  % Trial stimulus period Shake Request sum activation 
    'default', ...  % Trial delay period Shake Request sum activation 
    'default', ...  % Trial period Shake GoE sum activation 
    'default', ...  % Trial stimulus period Shake GoE sum activation 
    'default', ...  % Trial delay period Shake GoE sum activation  
    'default', ...  % Trial period Shake GoI sum activation 
    'default', ...  % Trial stimulus period Shake GoI sum activation 
    'default', ...  % Trial delay period Shake GoI sum activation
    'default', ...  % Trial period Shake NoGo sum activation 
    'default', ...  % Trial stimulus period Shake NoGo sum activation 
    'default', ...  % Trial delay period Shake NoGo sum activation  
    'default', ...  % Trial period Shake Init unit activation 
    'default', ...  % Trial stimulus period Shake Init unit activation 
    'default', ...  % Trial delay period Shake Init unit activation    
    'default', ...  % Trial period N/S Conflict unit activation 
    'default', ...  % Trial stimulus period N/S Conflict unit activation 
    'default'  ...  % Trial delay period N/S Conflict unit activation        
    );

% Set up (in order of plot IDs) y axis settings.  Each row is a plot = 
% [ custom? min_y max_y min_y_tick max_y_tick ]
y_axis_layout = [ ...
      0  -1  11   0  10; ...  % Color of stimulus
      0  -1  11   0  10; ...  % Tone stimulus context
      1   0   3   0   3; ...  % Behavior execution 
      0  -1  11   0  10; ...  % Errors    
      0  -1  11   0  10; ...  % Reinforcement activation 
      0  -1  11   0  10; ...  % Moving 3-window percent correct  
      0  -1  11   0  10; ...  % Moving 5-window percent correct  
      0  -1  11   0  10; ...  % Moving 7-window percent correct 
      0  -1  11   0  10; ...  % Moving 13-window percent correct  
      0  -1  11   0  10; ...  % Trial period color working memory unit activation
      0  -1  11   0  10; ...  % Trial stimulus period color working memory unit activation       
      0  -1  11   0  10; ...  % Trial delay period color working memory unit activation  
      0  -1  11   0  10; ...  % Trial period tone working memory unit activation
      0  -1  11   0  10; ...  % Trial stimulus period tone working memory unit activation       
      0  -1  11   0  10; ...  % Trial delay period tone working memory unit activation      
      1  -0.05  0.25  0  0.2; ...  % Trial period novelty unit activation
      1  -0.05  0.25  0  0.2; ...  % Trial stimulus period novelty unit activation       
      1  -0.05  0.25  0  0.2; ...  % Trial delay period novelty unit activation  
      0  -1  11   0  10; ...  % Trial period DA unit activation
      0  -1  11   0  10; ...  % Trial stimulus period DA unit activation       
      0  -1  11   0  10; ...  % Trial delay period DA unit activation 
      0  -1  11   0  10; ...  % Trial period frustration unit activation
      0  -1  11   0  10; ...  % Trial stimulus period frustration unit activation       
      0  -1  11   0  10; ...  % Trial delay period frustration unit activation       
      1  -0.05  0.55  0  0.5; ...  % Trial period Babble Request unit activation
      1  -0.05  0.55  0  0.5; ...  % Trial stimulus period Babble Request unit activation       
      1  -0.05  0.55  0  0.5; ...  % Trial delay period Babble Request unit activation 
      0  -1  11   0  10; ...  % Trial period Babble GoE sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Babble GoE sum activation       
      0  -1  11   0  10; ...  % Trial delay period Babble GoE sum activation 
      0  -1  11   0  10; ...  % Trial period Babble GoI sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Babble GoI sum activation       
      0  -1  11   0  10; ...  % Trial delay period Babble GoI sum activation  
      0  -1  11   0  10; ...  % Trial period Babble NoGo sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Babble NoGo sum activation       
      0  -1  11   0  10; ...  % Trial delay period Babble NoGo sum activation    
      1  -0.05  0.55  0  0.5; ...  % Trial period Babble Init unit activation
      1  -0.05  0.55  0  0.5; ...  % Trial stimulus period Babble Init unit activation       
      1  -0.05  0.55  0  0.5; ...  % Trial delay period Babble Init unit activation   
      0  -1  11   0  10; ...  % Trial period Babble Exec unit activation
      0  -1  11   0  10; ...  % Trial stimulus period Babble Exec unit activation       
      0  -1  11   0  10; ...  % Trial delay period Babble Exec unit activation 
      0  -1  11   0  10; ...  % Trial period Babble sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Babble sum activation       
      0  -1  11   0  10; ...  % Trial delay period Babble sum activation 
      1  -0.1  4.1  0  4; ...  % Trial period Plan sum activation
      1  -0.1  4.1  0  4; ...  % Trial stimulus period Plan sum activation       
      1  -0.1  4.1  0  4; ...  % Trial delay period Plan sum activation      
      0  -1  11   0  10; ...  % Trial period Nod Request sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Nod Request sum activation       
      0  -1  11   0  10; ...  % Trial delay period Nod Request sum activation 
      0  -1  11   0  10; ...  % Trial period Nod GoE sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Nod GoE sum activation       
      0  -1  11   0  10; ...  % Trial delay period Nod GoE sum activation  
      0  -1  11   0  10; ...  % Trial period Nod GoI sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Nod GoI sum activation       
      0  -1  11   0  10; ...  % Trial delay period Nod GoI sum activation  
      0  -1  11   0  10; ...  % Trial period Nod NoGo sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Nod NoGo sum activation       
      0  -1  11   0  10; ...  % Trial delay period Nod NoGo sum activation 
      0  -1  11   0  10; ...  % Trial period Nod Init unit activation
      0  -1  11   0  10; ...  % Trial stimulus period Nod Init unit activation       
      0  -1  11   0  10; ...  % Trial delay period Nod Init unit activation 
      0  -1  11   0  10; ...  % Trial period Shake Request sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Shake Request sum activation       
      0  -1  11   0  10; ...  % Trial delay period Shake Request sum activation 
      0  -1  11   0  10; ...  % Trial period Shake GoE sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Shake GoE sum activation       
      0  -1  11   0  10; ...  % Trial delay period Shake GoE sum activation  
      0  -1  11   0  10; ...  % Trial period Shake GoI sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Shake GoI sum activation       
      0  -1  11   0  10; ...  % Trial delay period Shake GoI sum activation  
      0  -1  11   0  10; ...  % Trial period Shake NoGo sum activation
      0  -1  11   0  10; ...  % Trial stimulus period Shake NoGo sum activation       
      0  -1  11   0  10; ...  % Trial delay period Shake NoGo sum activation 
      0  -1  11   0  10; ...  % Trial period Shake Init unit activation
      0  -1  11   0  10; ...  % Trial stimulus period Shake Init unit activation       
      0  -1  11   0  10; ...  % Trial delay period Shake Init unit activation 
      0  -1  11   0  10; ...  % Trial period N/S Conflict unit activation
      0  -1  11   0  10; ...  % Trial stimulus period N/S Conflict unit activation       
      0  -1  11   0  10  ...  % Trial delay period N/S Conflict unit activation       
      ];

num_avail_plots = size(y_axis_layout,1);

%
% Color definitions.
%
col_red =    [1    0   0];
col_orange = [1    0.5 0];
col_yellow = [1    1   0];
col_green =  [0    1   0];
col_blue =   [0    0   1];
col_indigo = [0.5  0   1];
col_violet = [1    0   1];
col_black =  [0    0   0];
col_white =  [1    1   1];

% 
% Set up figure for plotting.
%

% Set up the figure window.
small_window = 0;
if (small_window == 1)
    l_fig_pos = 0.01;
    b_fig_pos = 0.05;
    fig_w = 0.7;
    fig_h = 0.6;
else
    l_fig_pos = 0.01;
    b_fig_pos = 0.05;
    fig_w = 0.9;
    fig_h = 0.85;
end;
% fh = figure(1);
fh = figure;
set(fh,'Units','normalized');
set(fh,'Position',[l_fig_pos b_fig_pos fig_w fig_h]);
colormap(gray);

% Lay out the subplots.
num_plots = size(disp_plot_map,2);
subplot_inds = zeros(num_avail_plots,3);
for ii = 1:num_avail_plots
    x = find(disp_plot_map == ii);
    subplot_inds(ii,1) = num_plots;
    subplot_inds(ii,2) = 1;
    if (isempty(x))
        subplot_inds(ii,3) = 0;
    else
        subplot_inds(ii,3) = x;
    end;
end;

%
% Plot color of stimulus.
%
plot_id = 1;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot red stimuli.
    the_plot = trial_colors(1,:);
    ah = bar(the_plot);
    set(ah,'FaceColor',col_red);
    hold on;
    
    % Plot green stimuli.
    the_plot = trial_colors(2,:);
    ah = bar(the_plot);
    set(ah,'FaceColor',col_green);    
    
    % Plot blue stimuli.
    the_plot = trial_colors(3,:);
    ah = bar(the_plot);
    set(ah,'FaceColor',col_blue); 
    
    % Plot yellow stimuli.
    the_plot = trial_colors(1,:) .* trial_colors(2,:);
    ah = bar(the_plot);
    set(ah,'FaceColor',col_yellow);     
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Square Color';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot tone context of square stimulus.
%
plot_id = 2;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot C tone stimuli.
    the_plot = trial_tones(1,:);
    ah = bar(the_plot);
    set(ah,'FaceColor',col_blue);  
    hold on;

    % Plot Eb tone stimuli.
    the_plot = trial_tones(4,:);
    ah = bar(the_plot);
    set(ah,'FaceColor',col_red); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Tone Context';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot behavior execution (Track/Nod/Shake/Both).
%
plot_id = 3;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the Nod data.
    the_plot = trial_nod_counts;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_green); 
    hold on;
    
    % Plot the Shake data.
    the_plot = trial_shake_counts;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_red);  
    
    % Plot the Nod/Shake data.
    the_plot = trial_nod_counts .* trial_shake_counts;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_yellow); 
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Behavior';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot error occurences.
%
plot_id = 4;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));

    % Plot correct responses.
    the_plot = trials_correct;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_green);   
    hold on; 
    
    % Plot misses.
    the_plot = trials_missed;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_black); 
 
    % Plot opposite responses.
    the_plot = trials_incorrect;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_red); 
       
    % Plot trials which have both nods and shakes.
    the_plot = trials_conflict;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_yellow);   
    
    % Plot correct, but (also) extra responses.
    the_plot = trials_extra_resp;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_blue); 
    
    % Plot late response trials.
    the_plot = trials_late;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_orange); 
      
% 
%     % Plot blind responses.
%     the_plot = zeros(1,num_iters);
%     event_iters = [ blind_nod blind_shake ];
%     mark_idx = event_iters;
%     mark_idx = [ mark_idx (event_iters + 1) ];
%     mark_idx = [ mark_idx (event_iters + 2) ];
%     mark_idx = [ mark_idx (event_iters + 3) ];
%     mark_idx = [ mark_idx (event_iters + 4) ];
%     mark_idx(find(mark_idx > num_iters)) = [];
%     the_plot(mark_idx) = 1;
%     ah = area(the_plot);
%     set(ah,'FaceColor',col_violet);
    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Errors';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot reinforcement activation (reward or punishment).
%
plot_id = 5;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the reward data.
    the_plot = trial_reward_counts;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_green); 
    hold on; 
    
    % Plot the punisher data.
    the_plot = trial_punish_counts;
    ah = bar(the_plot);
    set(ah,'FaceColor',col_red);    
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Reinf';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot 3 point percentage of average accuracy.
%
plot_id = 6;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the reward data.
    the_plot = [ 0 trial_win3_accur 0 ];
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = '% Corr (of 3)';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot 5 point percentage of average accuracy.
%
plot_id = 7;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the reward data.
    the_plot = [ 0 0 trial_win5_accur 0 0 ];
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = '% Corr (of 5)';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot 7 point percentage of average accuracy.
%
plot_id = 8;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the reward data.
    the_plot = [ 0 0 0 trial_win7_accur 0 0 0 ];
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = '% Corr (of 7)';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot 13 point percentage of average accuracy.
%
plot_id = 9;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the reward data.
    the_plot = [ 0 0 0 0 0 0 trial_win13_accur 0 0 0 0 0 0 ];
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = '% Corr (of 13)';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period color working memory unit activation.
%
plot_id = 10;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_color_wm_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'ColorWM TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period color working memory unit activation.
%
plot_id = 11;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_color_wm_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'ColorWM TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period color working memory unit activation.
%
plot_id = 12;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_color_wm_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'ColorWM TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period tone working memory unit activation.
%
plot_id = 13;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_tone_wm_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'ToneWM TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period tone working memory unit activation.
%
plot_id = 14;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_tone_wm_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'ToneWM TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period tone working memory unit activation.
%
plot_id = 15;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_tone_wm_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'ToneWM TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period novelty unit activation.
%
plot_id = 16;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_novelty;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Novelty TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period novelty unit activation.
%
plot_id = 17;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_novelty;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Novelty TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period novelty unit activation.
%
plot_id = 18;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_novelty;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Novelty TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period DA unit activation.
%
plot_id = 19;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_DA;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'DA TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period DA unit activation.
%
plot_id = 20;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_DA;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'DA TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period DA unit activation.
%
plot_id = 21;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_DA;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'DA TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period frustration unit activation.
%
plot_id = 22;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_frust;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Frust TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period frustration unit activation.
%
plot_id = 23;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_frust;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Frust TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period frustration unit activation.
%
plot_id = 24;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_frust;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Frust TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble Request unit activation.
%
plot_id = 25;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_req;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BReq TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble Request unit activation.
%
plot_id = 26;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_req;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BReq TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble Request unit activation.
%
plot_id = 27;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_req;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BReq TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble GoE sum activation.
%
plot_id = 28;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BGoE TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble GoE sum activation.
%
plot_id = 29;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BGoE TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble GoE sum activation.
%
plot_id = 30;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BGoE TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble GoI sum activation.
%
plot_id = 31;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BGoI TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble GoI sum activation.
%
plot_id = 32;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BGoI TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble GoI sum activation.
%
plot_id = 33;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BGoI TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble NoGo sum activation.
%
plot_id = 34;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BNoGo TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble NoGo sum activation.
%
plot_id = 35;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BNoGo TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble NoGo sum activation.
%
plot_id = 36;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BNoGo TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble Init unit activation.
%
plot_id = 37;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BInit TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble Init unit activation.
%
plot_id = 38;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BInit TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble Init unit activation.
%
plot_id = 39;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BInit TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble Init unit activation.
%
plot_id = 37;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BInit TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble Init unit activation.
%
plot_id = 38;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BInit TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble Init unit activation.
%
plot_id = 39;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BInit TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble Exec unit activation.
%
plot_id = 40;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_exec;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BExec TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble Exec unit activation.
%
plot_id = 41;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_exec;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BExec TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble Exec unit activation.
%
plot_id = 42;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_exec;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'BExec TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Babble sum activation.
%
plot_id = 43;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_babble_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Babble TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Babble sum activation.
%
plot_id = 44;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_babble_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Babble TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Babble sum activation.
%
plot_id = 45;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_babble_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Babble TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Plan sum activation.
%
plot_id = 46;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_plan_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Plan TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Plan sum activation.
%
plot_id = 47;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_plan_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Plan TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Plan sum activation.
%
plot_id = 48;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_plan_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Plan TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Nod Request sum activation.
%
plot_id = 49;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_nod_req_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NReq TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Nod Request sum activation.
%
plot_id = 50;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_nod_req_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NReq TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Nod Request sum activation.
%
plot_id = 51;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_nod_req_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NReq TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Nod GoE sum activation.
%
plot_id = 52;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_nod_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NGoE TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Nod GoE sum activation.
%
plot_id = 53;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_nod_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NGoE TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Nod GoE sum activation.
%
plot_id = 54;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_nod_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NGoE TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Nod GoI sum activation.
%
plot_id = 55;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_nod_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NGoI TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Nod GoI sum activation.
%
plot_id = 56;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_nod_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NGoI TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Nod GoI sum activation.
%
plot_id = 57;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_nod_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NGoI TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Nod NoGo sum activation.
%
plot_id = 58;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_nod_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NNoGo TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Nod NoGo sum activation.
%
plot_id = 59;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_nod_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NNoGo TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Nod NoGo sum activation.
%
plot_id = 60;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_nod_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NNoGo TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Nod Init unit activation.
%
plot_id = 61;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_nod_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NInit TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Nod Init unit activation.
%
plot_id = 62;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_nod_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NInit TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Nod Init unit activation.
%
plot_id = 63;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_nod_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'NInit TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Shake Request sum activation.
%
plot_id = 64;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_shake_req_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SReq TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Shake Request sum activation.
%
plot_id = 65;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_shake_req_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SReq TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Shake Request sum activation.
%
plot_id = 66;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_shake_req_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SReq TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Shake GoE sum activation.
%
plot_id = 67;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_shake_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SGoE TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Shake GoE sum activation.
%
plot_id = 68;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_shake_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SGoE TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Shake GoE sum activation.
%
plot_id = 69;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_shake_go_e_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SGoE TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Shake GoI sum activation.
%
plot_id = 70;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_shake_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SGoI TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Shake GoI sum activation.
%
plot_id = 71;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_shake_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SGoI TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Shake GoI sum activation.
%
plot_id = 72;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_shake_go_i_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SGoI TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Shake NoGo sum activation.
%
plot_id = 73;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_shake_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SNoGo TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Shake NoGo sum activation.
%
plot_id = 74;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_shake_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SNoGo TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Shake NoGo sum activation.
%
plot_id = 75;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_shake_nogo_sum;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SNoGo TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period Shake Init unit activation.
%
plot_id = 76;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_shake_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SInit TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period Shake Init unit activation.
%
plot_id = 77;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_shake_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SInit TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period Shake Init unit activation.
%
plot_id = 78;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_shake_init;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'SInit TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial period N/S Conflict unit activation.
%
plot_id = 79;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_ns_conflict;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Conflict TrP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial stimulus period N/S Conflict unit activation.
%
plot_id = 80;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_stim_ns_conflict;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Conflict TrStP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot trial delay period N/S Conflict unit activation.
%
plot_id = 81;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Plot the data.
    the_plot = ave_tr_del_ns_conflict;
    ah = bar(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_trial max_trial min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_trial - min_trial) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = 'Conflict TrDP';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_trial-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

% Show the title in the first subplot.
subplot(num_plots,1,1);
title(plot_title);

% Null out the X tick labels for all but the last subplot.
for ii = 1:(num_plots - 1);
    subplot(num_plots,1,ii);
    set(gca,'XTickLabel',[]);
end;

% Show the iterations in the last subplot.
subplot(num_plots,1,num_plots);
xlabel('Trials');