%
% cog_model_brain.m
%
% Run the brain according to the neural cognitive model.
%
% Last modification: 10/26/07


% Brain inputs we have to work with...
% stim_on             % is the stimulus on?
% color_map(1)        % Red unit
% color_map(2)        % Green unit
% color_map(3)        % Blue unit
% color_map(4)        % Yellow unit
% mem_color_map(1-4)  % Memory for colors
% tones_map(1-12)     % Tones C through B
% mem_tones_map(1-12) % Memory for tones C through B
% reward_on = 0;      % is there currently a reward?
% punish_on = 0;      % is there currently a punishment?
% reward_delivered;   % has a reward been delivered?
% punish_delivered;   % has a punisher been delivered?
% track_execute = 0;  % is the Track behavior on?
% nod_execute = 0;    % is the Nod behavior on?
% shake_execute = 0;  % is the Shake behavior on?
% tonic_DA_input      % what is the tonic level of DA cell firing activity?
% novelty_on = 0;     % is there a novel stimulus present?


% Remember the past CS (conditioned stimulus) activities.  (adaptive critic
% code)
% CS_past_activs = [ Spast(RedMemUnit_ind:YellowMemUnit_ind) ...
%     Spast(CMemUnit_ind:BMemUnit_ind) ]';

% Copy the input information into the appropriate input units.
Spast(VisStimOnUnit_ind) = stim_on;
Spast(RedUnit_ind:YellowUnit_ind) = color_map;
Spast(RedMemUnit_ind:YellowMemUnit_ind) = mem_color_map;
Spast(CUnit_ind:BUnit_ind) = tones_map;
Spast(CMemUnit_ind:BMemUnit_ind) = mem_tones_map;
Spast(RewardUnit_ind) = reward_on;
Spast(PunisherUnit_ind) = punish_on;
Spast(ReinfMemUnit_ind) = reward_delivered;
Spast(ReinfMemUnit_ind + 1) = punish_delivered;
Spast(TrackExecUnit_ind) = track_execute;
Spast(NodExecUnit_ind) = nod_execute;
Spast(ShakeExecUnit_ind) = shake_execute;
% Spast(TonicDAAffUnit_ind) = tonic_DA_input;
Spast(NoveltyUnit_ind) = novelty_on;

%
% Code for the adaptive critic
%

% Extract the (current) CS activations and the CS to reward prediction 
% weights.
% CS_activs = [ Spast(RedMemUnit_ind:YellowMemUnit_ind) ...
%     Spast(CMemUnit_ind:BMemUnit_ind) ]';
% rew_pred_wts = CW(rew_pred_CW_ind);

% For all of the CSs...
% for xx = 1:num_CS
%     % Reset all "intracellular calcium" counters for the CS to -1 if the
%     % corresponding CS was off on the previous time-step and has just
%     % turned on.
%     if ((CS_past_activs(xx) <= CS_thresh) && (CS_activs(xx) > CS_thresh))
%         rew_pred_ic_ct(:,xx) = -min_rew_delay;
%     end;
%     
%     % Increment every "intracellular calcium" counter for the CS if it is
%     % currently on.
%     if (CS_activs(xx) > CS_thresh)
%         rew_pred_ic_ct(:,xx) = rew_pred_ic_ct(:,xx) + 1;
%     end;    
% end;

% Find the excitatory net input of the reward prediction delay units.
% for yy = 1:num_rew_delays
%     for xx = 1:num_CS
%         if (rew_pred_ic_ct(yy,xx) == yy)
%             rew_pred_act_wts(yy,xx) = rew_pred_wts(yy,xx);
%             rew_pred_wt_elig((xx - 1) * num_rew_delays + yy) = 1;
%         else
%             rew_pred_act_wts(yy,xx) = 0;
%             rew_pred_wt_elig((xx - 1) * num_rew_delays + yy) = 0;
%         end;
%     end;
% end;
% rew_pred_CT = Cell_type(RewPredict_ind);
% rew_pred_netin = rew_pred_act_wts * CS_activs;
% rew_pred_out = Spast(RewPredictLoUnit:RewPredictHiUnit)';
% rew_pred_out = rew_pred_out + (iter_duration / 1000.0) .* ...
%     wcunitupdate(rew_pred_out,rew_pred_netin,thresh(rew_pred_CT), ...
%     gain(rew_pred_CT),namp(rew_pred_CT),1 ./ outtimeconst(rew_pred_CT), ...
%     1 ./ outtimeconst(rew_pred_CT));

% Determine whether a stimulus is present right now.
stim_present = (sum(color_map) > 0.3);

% Increment the frustration level.
frustration_level = frustration_level + frust_inc;

% Increment the frustration level according to the tonic level of DA.
% frustration_level = frustration_level + ...
%     tonic_DA_input * tonic_DA_frust_wt;

% Decrement the frustration level if there is a reward or reward predictor.
frustration_level = frustration_level - ...    
    reward_on * reward_frust_inhib_wt;

if (frust_bhvr_reset == 1)
    frustration_level = frustration_level - ...
        babble_exec_act * babble_exec_frust_inhib_wt;   
end;

% frustration_level = frustration_level - ...
%     babble_exec_act * babble_exec_frust_inhib_wt - .... 
%     reward_on * reward_frust_inhib_wt - ....    
%     Spast(RewardCueUnit_ind) * reward_cue_frust_inhib_wt;

% Clip the frustration level between 0 and 1.
if (frustration_level < 0.0)
    frustration_level = 0.0;
elseif (frustration_level > 1.0)
    frustration_level = 1.0;
end;

% Update the activation of the frustration unit now so we can use its new
% value this iteration.
Spast(FrustrationUnit_ind) = frustration_level;

% OLD BABBLE CODE: could probably delete
%
% % Increment the babble drive level according to the tonic level of DA, and 
% % the novelty signal.
% babble_req_level = babble_req_level + ...
%     tonic_DA_input * tonic_DA_babble_wt + novelty_on * novelty_babble_wt;
% 
% % Decrement the babble drive level according to the babble exec activity, 
% % reward, and reward predictor activity.
% babble_req_level = babble_req_level - ...
%     babble_exec_act * babble_exec_babble_wt - ....
%     reward_on * reward_babble_wt - ....    
%     Spast(RewardCueUnit_ind) * reward_cue_babble_wt;
% 
% % Clip the babble_req level between 0 and 1.
% if (babble_req_level < 0.0)
%     babble_req_level = 0.0;
% elseif (babble_req_level > 1.0)
%     babble_req_level = 1.0;
% end;
% 
% % If our babble request level is over the babble exec threshold and we're  
% % not nodding or shaking or otherwise babbling...
% if ((babble_req_level > babble_exec_thresh) && ...
%     (nod_execute == 0) && (shake_execute == 0) && ...
%     (babble_iter_count == 0) && (stim_present == 1))
%     babble_count = babble_count + 1;
%     babble_exec_act = 1.0;
%     last_babble_start_iter = iter;
%     babble_iter_count = babble_iter_dur;
% end;
% 
% % Update the babble exec unit in case it's been turned on.
% Spast(BabbleExecUnit_ind) = babble_exec_act;


% Update the neural dice set unit here, if appropriate.  Pattern is to
% start with an unset period of nd_throw_duration and alternate,
% thereafter, between set and unset periods of set durations.
% if (mod(iter,nd_throw_duration + nd_set_duration) == 1)
%     neural_dice_set = 0.0;
% elseif (mod(iter,nd_throw_duration + nd_set_duration) == nd_throw_duration + 1)
%     neural_dice_set = 1.0;
% end;

% Turn on the dice set if a visual stimulus is present.
neural_dice_set = stim_on;

% Update the neural dice set unit activation in case it's been turned on.
Spast(DiceSetUnit_ind) = neural_dice_set;

% Adjust the output activation function of the neural dice excitatory units
% according to the set unit activity.
if (neural_dice_set > neural_dice_set_thresh)
    gain(neural_dice_CT) = dice_set_gain;  
else
    gain(neural_dice_CT) = dice_unset_gain; 
end;

% Update the neural dice gating unit here.  It follows the pattern of the
% set unit.
% if (mod(iter,nd_throw_duration + nd_set_duration) == 1)
%     neural_dice_gate = 0.0;
% elseif (mod(iter,nd_throw_duration + nd_set_duration) == nd_throw_duration + 1)
%     neural_dice_gate = 1.0;
% end;

% Turn on the dice gate if a visual stimulus is present.
neural_dice_gate = stim_on;

% Update the neural dice gate unit activation in case it's been turned on.
Spast(DiceGateUnit_ind) = neural_dice_gate;

% Activate Babble Exec Unit and set the countdown if the Babble Init unit 
% has a high enough activation and the countdown is completely run down.
if ((Spast(BabbleInitUnit_ind) > babble_exec_thresh) && ...
    (babble_iter_count == -babble_refrac_dur))
    babble_count = babble_count + 1;
    babble_exec_act = 1.0;
    last_babble_start_iter = iter;
    babble_iter_count = babble_iter_dur;
end;

% Update the babble exec unit in case it's been turned on.
Spast(BabbleExecUnit_ind) = babble_exec_act;

% Adjust the output activation function of the babble dice units according 
% to the babble exec unit activity.
if (babble_exec_act > babble_dice_set_thresh)
    gain(babble_dice_CT) = babble_dice_set_gain;
else
    gain(babble_dice_CT) = babble_dice_unset_gain;
end;

% Adjust the output activation function of the DA modulated units according
% to the current DA cell firing (from the previous time step).
thresh(modDA_CTind) = 2.0 * (hi_DA_thresh(modDA_CTind) - ...
    mid_DA_thresh(modDA_CTind)) .* ...
    sigm(norm_DA_level,DA_thresh_scale_gain, ...
    Spast(DAeff_mod_units(modDA_CTind))) + ...
    2.0 * mid_DA_thresh(modDA_CTind) - hi_DA_thresh(modDA_CTind);
gain(modDA_CTind) = 2.0 * (hi_DA_gain(modDA_CTind) - ...
    mid_DA_gain(modDA_CTind)) .* ...
    sigm(norm_DA_level,DA_gain_scale_gain, ...
    Spast(DAeff_mod_units(modDA_CTind))) + ...
    2.0 * mid_DA_gain(modDA_CTind) - hi_DA_gain(modDA_CTind);

% Save the base thresholds for plotting.
base_threshs(:,iter) = thresh(CT)';

% First sum all of the voltage-independent glutamate inputs.  VI(CH) is the 
% filter for voltage-independent inputs.  ~inhib(CH) filters out the 
% inhibitory units.
Avie = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC), ...
    VI(CH) .* ~inhib(CH) .* CW .* Spast(CA(2,:))),2)';

% Next, sum all of the voltage-independent GABA inputs.  VI(CH) is the 
% filter for voltage-independent inputs.  inhib(CH) filters the inhibitory 
% units.
Avii = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC), ...
    VI(CH) .* inhib(CH) .* CW .* Spast(CA(2,:))),2)';

% Then sum all the voltage-dependent inputs.
% vd_thresh = 0.3;
% vd_gain = 50;
% % vd_thresh = 50.0;
% Avd = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),~VI(CH) ...
%     .*sigm(vd_thresh,vd_gain,Avi(CA(1,:))) ...
%     .*CW.*Spast(CA(2,:))),2)';

% Run kWTA sigmoidal adjustments.
thresh_adj = zeros(1,sum(NU));
for xx = 1:num_kWTA_area_pools
    k = kWTA_pool_kvals(xx);
    unit_inds = kWTA_pool_unit_inds(xx,1:kWTA_pool_sizes(xx));
    netins = Avie(unit_inds) - Avii(unit_inds);
    num_thresh_xings = sum(sum(netins > thresh(kWTA_pool_thresh_inds(xx))));  
    if (num_thresh_xings > k)
        sort_netins = sort(reshape(netins,1,size(unit_inds,1) * ...
            size(unit_inds,2)),'descend');
        new_thresh = (sort_netins(k) + sort_netins(k+1)) / 2.0;
        thresh_adj(unit_inds) = new_thresh - ...
            thresh(kWTA_pool_thresh_inds(xx));
    end;
end;

% Save the threshold adjustments for future plotting.
thresh_adjs(:,iter) = thresh_adj';

% Update unit activity (using Euler's approximation for simulating).
% S = Spast + wcunitupdate(Spast,Avi+Avd,thresh(CT),gain(CT),namp(CT), ...
%     outtimeconst(CT),outtimeconst(CT));
S = Spast + (iter_duration / 1000.0) .* ...
    wcunitupdate(Spast,Avie - Avii,thresh(CT) + thresh_adj,gain(CT), ...
    namp(CT), 1 ./ outtimeconst(CT),1 ./ outtimeconst(CT));

% Update the DA cell activity, and the DA effects units.
tonic_DA_out = S(TonicDAAffUnit_ind);
% rew_cue_out = S(RewardCueUnit_ind);
% rew_cue_thresh = 0.85;
DASig_CT = Cell_type(DASignal_ind);
% DASig_netin = DA_tonic_input_wt * tonic_DA_out + ...
%     novelty_input_wt * novelty_on + ...
%     DA_frust_wt * frustration_level + ...
%     DA_rew_cue_wt * rew_cue_out * (rew_cue_out > rew_cue_thresh) - ...
%     DA_rew_pred_wts' * rew_pred_out - ...
%     punish_input_wt * punish_on;
DASig_netin = DA_tonic_input_wt * tonic_DA_out + ...
    novelty_input_wt * novelty_on + ...
    DA_frust_wt * frustration_level + ...    
    reward_input_wt * reward_on - ...    
    punish_input_wt * punish_on;
DASig_out = Spast(DAUnit_ind);
DASig_out = DASig_out + (iter_duration / 1000.0) .* ...
    wcunitupdate(DASig_out,DASig_netin,thresh(DASig_CT), ...
    gain(DASig_CT),namp(DASig_CT),1 ./ outtimeconst(DASig_CT), ...
    1 ./ outtimeconst(DASig_CT));
DAPlanEff = DASig_out + DA_global_agon + DA_plan_unit_agon;
if (DAPlanEff < 0.0)
    DAPlanEff = 0.0;
elseif (DAPlanEff > 1.0)
    DAPlanEff = 1.0;
end;
DAReqEff = DASig_out + DA_global_agon + DA_req_unit_agon;
if (DAReqEff < 0.0)
    DAReqEff = 0.0;
elseif (DAReqEff > 1.0)
    DAReqEff = 1.0;
end;
DANodShakeGoEff = DASig_out + DA_global_agon + DA_nodshake_go_agon;
if (DANodShakeGoEff < 0.0)
    DANodShakeGoEff = 0.0;
elseif (DANodShakeGoEff > 1.0)
    DANodShakeGoEff = 1.0;
end;
DANodShakeNoGoEff = DASig_out + DA_global_agon + DA_nodshake_nogo_agon;
if (DANodShakeNoGoEff < 0.0)
    DANodShakeNoGoEff = 0.0;
elseif (DANodShakeNoGoEff > 1.0)
    DANodShakeNoGoEff = 1.0;
end;
DABabbleGoEff = DASig_out + DA_global_agon + DA_babble_go_agon;
if (DABabbleGoEff < 0.0)
    DABabbleGoEff = 0.0;
elseif (DABabbleGoEff > 1.0)
    DABabbleGoEff = 1.0;
end;
DABabbleNoGoEff = DASig_out + DA_global_agon + DA_babble_nogo_agon;
if (DABabbleNoGoEff < 0.0)
    DABabbleNoGoEff = 0.0;
elseif (DABabbleNoGoEff > 1.0)
    DABabbleNoGoEff = 1.0;
end;

% Activate the Nod behavior if the first output unit has a high enough 
% activation.
if (S(NodInitUnit_ind) > premotor_exec_thresh)
    nod_execute = 1;
end;

% Activate the Nod behavior if the first output unit has a high enough 
% activation.
if (S(ShakeInitUnit_ind) > premotor_exec_thresh)
    shake_execute = 1;
end;

% Count down the neural dice timer.
% if (neural_dice_iter_count > 0)
%     neural_dice_iter_count = neural_dice_iter_count - 1;
%     if (neural_dice_iter_count == 0)
%         neural_dice_set = 0;
%         neural_dice_gate = 0;
%     end;
% end;

% Count down the babble timer, and turn off the babble exec unit if we've 
% been active the full time.
if (babble_iter_count > -babble_refrac_dur)
    babble_iter_count = babble_iter_count - 1;
    if (babble_iter_count == 0)
        babble_exec_act = 0.0;
        if ((last_nod_start_iter > last_babble_start_iter) && ...
            (last_shake_start_iter > last_babble_start_iter))
            nod_shake_babble_count = nod_shake_babble_count + 1;
        elseif (last_nod_start_iter > last_babble_start_iter)
            nod_babble_count = nod_babble_count + 1;
        elseif (last_shake_start_iter > last_babble_start_iter)
            shake_babble_count = shake_babble_count + 1;
        end;        
    end;
end;

% Copy the inputs back to the initial units so the inputs are correctly 
% remembered.
S(VisStimOnUnit_ind) = stim_on;
S(RedUnit_ind:YellowUnit_ind) = color_map;
S(RedMemUnit_ind:YellowMemUnit_ind) = mem_color_map;
S(CUnit_ind:BUnit_ind) = tones_map;
S(CMemUnit_ind:BMemUnit_ind) = mem_tones_map;
S(RewardUnit_ind) = reward_on;
S(PunisherUnit_ind) = punish_on;
S(ReinfMemUnit_ind) = reward_delivered;
S(ReinfMemUnit_ind + 1) = punish_delivered;
S(TrackExecUnit_ind) = track_execute;
S(NodExecUnit_ind) = nod_execute;
S(ShakeExecUnit_ind) = shake_execute;
% S(TonicDAAffUnit_ind) = tonic_DA_input;
S(NoveltyUnit_ind) = novelty_on;

% Overwrite the DA critic output activations calculated in the
% default calculation with the proper outputs.
% S(RewPredictLoUnit:RewPredictHiUnit) = rew_pred_out;
S(DAUnit_ind) = DASig_out;
S(DAPlanEffUnit_ind) = DAPlanEff;
S(DAReqEffUnit_ind) = DAReqEff;
S(DANodShakeGoEffUnit_ind) = DANodShakeGoEff;
S(DANodShakeNoGoEffUnit_ind) = DANodShakeNoGoEff;
S(DABabbleGoEffUnit_ind) = DABabbleGoEff;
S(DABabbleNoGoEffUnit_ind) = DABabbleNoGoEff;

% Overwrite the frustration unit output activations calculated in the
% default calculation with the proper outputs.
S(FrustrationUnit_ind) = frustration_level;

% Overwrite the neural dice set and gate unit output activations 
% calculated in the default calculation with the proper outputs.
S(DiceSetUnit_ind) = neural_dice_set;
S(DiceGateUnit_ind) = neural_dice_gate;

% Overwrite the babble exec unit output activations calculated in the
% default calculation with the proper outputs.
S(BabbleExecUnit_ind) = babble_exec_act;

% Do learning if learning is on.
if (learning_on == 1)  
    % Check for disabling of eligibility traces, for example by NoGo
    % thalamic activity not being high enough.
    elig_disable = zeros(size(mdc,2),1);
    for xx = 1:size(NoGo_wt_inds,1)
        if (CW(NoGo_wt_inds(xx)) * S(NoGo_thal_in_unit_inds(xx)) < ...
                NoGo_thal_elig_thresh)
            elig_disable(NoGo_elig_dis_wt_inds(xx,:)) = 1;
        end;
    end;
            
    % Set the eligibility iteration count to the appropriate duration for 
    % each occurrence where the pre- and post-synaptic activations are high
    % enough.
    for xx = 1:size(mdc,2)
        if ((S(CA(1,mdc(xx))) > eligib_post_thresh(CH(mdc(xx)))) && ...
            (S(CA(2,mdc(xx))) > eligib_pre_thresh(CH(mdc(xx)))) && ...
            (elig_disable(xx) == 0))
            elig_iter_count(xx) = eligib_duration(CH(mdc(xx)));
        end;
    end;
    
    % Set the eligibility trace according to whether there is a count
    % running.
    elig_trace(:,iter) = (elig_iter_count > 0);
    
    % Decrement the eligibility iteration count by 1, making sure it
    % doesn't drop below 0.
    elig_iter_count = elig_iter_count - ones(size(mdc,2),1);
    elig_iter_count = elig_iter_count .* (elig_iter_count >= 0);

    % Overwrite the eligibility trace values for the reward prediction
    % weights according to what weights are active.
%     elig_trace(rew_pred_wt_elig_ind,iter) = rew_pred_wt_elig';
    
    % For each of the learnable weights...
    for xx = 1:size(mdc,2)
        DAeffect = S(DAeff_learn_units(CH(mdc(xx))));
        
        % Only if the eligibility trace is on...
        if (elig_trace(xx,iter) == 1)
            % If we should do LTP...
            if (((DA_LTP_hi(CH(mdc(xx))) == 1) && ...
                (DAeffect > DA_plastic_hi_thresh(CH(mdc(xx))))) || ...
                ((DA_LTP_hi(CH(mdc(xx))) == 0) && ...
                (DAeffect < DA_plastic_lo_thresh(CH(mdc(xx))))))
                CW(mdc(xx)) = CW(mdc(xx)) + LTP_learnrate(CH(mdc(xx)));
            % Else, if we should do LTD...
            elseif (((DA_LTP_hi(CH(mdc(xx))) == 1) && ...
                (DAeffect < DA_plastic_lo_thresh(CH(mdc(xx))))) || ...
                ((DA_LTP_hi(CH(mdc(xx))) == 0) && ...
                (DAeffect > DA_plastic_hi_thresh(CH(mdc(xx))))))
                CW(mdc(xx)) = CW(mdc(xx)) - LTD_learnrate(CH(mdc(xx)));
            end;
        end;
    end;
    
        % LTP term active if post- and pre-synaptic activity are high
        % enough and the reward is on...     
        % LTD term active if post-synaptic activity is high enough and the
        % presynaptic activity is over the LTD threshold but under the LTP
        % threshold, and the reward is on...
        % Weight decay term which is always active...   
%     CW(mdc) = CW(mdc) ...     
%         + learnrate(CH(mdc)) .* ...
%         (S(CA(1,mdc)) > LTP_LTD_postsyn_thresh) .* ...
%         (S(CA(2,mdc)) > LTP_presyn_thresh) .* ...
%         (S(DAUnit_ind) > LTP_LTD_DA_thresh) ...
%         - learnrate(CH(mdc)) .* LTD_decay_coeff .* ...
%         (S(CA(1,mdc)) > LTP_LTD_postsyn_thresh) .* ...
%         (S(CA(2,mdc)) > LTD_presyn_thresh) .* ...
%         (S(CA(2,mdc)) < LTP_presyn_thresh) .* ...
%         (S(DAUnit_ind) > LTP_LTD_DA_thresh);
 %       - wt_decay_rate; % should multiply by CW(mdc)...
     
    % Clip any weights that have fallen below 0 at 0.
    CW(mdc) = CW(mdc) .* (CW(mdc) >= 0);
      
    % Clip any weights that have risen over the max.
    hi_wt_ind = find(CW(mdc) > maxwt(CH(mdc)));
    CW(mdc(hi_wt_ind)) = maxwt(CH(mdc(hi_wt_ind)));
 
    % Normalize weights of fanin arbors that need to be normalized.
    for xx = 1:num_norm_arbors      
        norm_wt_ind = norm_arbor_wt_ind(xx,1:norm_arbor_size(xx));
        maxtotwt = norm_arbor_maxtotwt(xx);        
        totwt = sum(CW(norm_wt_ind));
        if (totwt > maxtotwt)
            CW(norm_wt_ind) = CW(norm_wt_ind) * maxtotwt / totwt;
        end;
    end;
    
    modCW(:,iter) = CW(mdc)';
    
% Otherwise (if learning is turned off)...
else
    % We want to make sure the babble weights are still being set in modCW
    % correctly.
    modCW(:,iter) = CW(mdc)';
end;

% Save unit activities for later display.
output(:,iter) = S';

% Remember the previous activations.
Spast = S;

% If we're ending the last iteration, do any cleanup stuff we need to.
if (iter == num_iters)
    disp('Simulation finished');
end;