%
% disp_trial_step.m
%
% Show a single iteration of a simulation trial.  load_pantilt_sim.m and 
% make_disp_fig.m need to be run first.
%
% Last modification: 3/22/08


% Load the activation data for the current time-step.
stim_on = stim_on_sv(iter);
stim_x = stim_x_sv(iter);
stim_y = stim_y_sv(iter);
stim_red = stim_red_sv(iter);
stim_green = stim_green_sv(iter);
stim_blue = stim_blue_sv(iter);
tones_on = tones_on_sv(:,iter);
reward_on = reward_on_sv(iter);
reward_trigger = reward_trigger_sv(iter);
reward_delivered = reward_delivered_sv(iter);
punish_on = punish_on_sv(iter);
camera_x = camera_x_sv(iter); 
camera_y = camera_y_sv(iter);
mem_color_map = mem_color_map_sv(:,iter);
mem_tones_map = mem_tones_map_sv(:,iter);
track_execute = track_execute_sv(iter);
nod_execute = nod_execute_sv(iter);
shake_execute = shake_execute_sv(iter);
if (brain_type == brain_cog_model)
    S = output(:,iter)'; 
    modCWcurr = modCW(:,iter)'; 
end;
time_ind = iter;

% Set whole scene map according to the stimulus' position.
% whole_scene is what the camera is able to see.
whole_scene = zeros(scene_height,scene_width,3);
if (stim_on == 1)
    for xx = 1:size(stim_shape,2)
        for yy = 1:size(stim_shape,1)
            whole_scene(floor(stim_y) + yy - 1, floor(stim_x) + xx - 1, 1) = ...
                stim_red * stim_shape(yy,xx);
            whole_scene(floor(stim_y) + yy - 1, floor(stim_x) + xx - 1, 2) = ...
                stim_green * stim_shape(yy,xx);
            whole_scene(floor(stim_y) + yy - 1, floor(stim_x) + xx - 1, 3) = ...
                stim_blue * stim_shape(yy,xx);
        end;
    end;
end;

% Set camera and fovea boundaries according to the camera's position.
camera_left_b = floor(camera_x);
camera_right_b = floor(camera_x) + camera_width - 1;
camera_top_b = floor(camera_y);
camera_bottom_b = floor(camera_y) + camera_height - 1;
fovea_left_b = floor(camera_x) + (camera_width - fovea_width) / 2.0;
fovea_right_b = fovea_left_b + fovea_width - 1;
fovea_top_b = floor(camera_y) + (camera_height - fovea_height) / 2.0;
fovea_bottom_b = fovea_top_b + fovea_height - 1;

% Set the retina rods map to the maximum of the colors in the camera window 
% on the scene.
retina_rods = zeros(64);
for xx = 1:camera_width
    for yy = 1:camera_height
        rod_val(1) = whole_scene(camera_top_b + yy - 1, ...
            camera_left_b + xx - 1, 1);
        rod_val(2) = whole_scene(camera_top_b + yy - 1, ...
            camera_left_b + xx - 1, 2);
        rod_val(3) = whole_scene(camera_top_b + yy - 1, ...
            camera_left_b + xx - 1, 3);        
        retina_rods(yy,xx) = max(rod_val);
    end;
end;

% Set the retina cones map to be the values seen in the foveal portion of 
% the camera.
retina_cones = zeros(16,16,3);
for xx = 1:fovea_width
    for yy = 1:fovea_height
        for kk = 1:3
            retina_cones(yy,xx,kk) = whole_scene(fovea_top_b + yy - 1, ...
                fovea_left_b + xx - 1, kk);
        end;
    end;
end;

% Set the color map units according to the color opponencies red vs. green 
% and blue vs. yellow.
color_map = zeros(4,1);
red_mean = mean(mean(retina_cones(:,:,1)));
green_mean = mean(mean(retina_cones(:,:,2)));
blue_mean = mean(mean(retina_cones(:,:,3)));
color_map(1) = red_mean - green_mean;  % Red+/Green- (red detector)
color_map(2) = green_mean - red_mean;  % Green+/Red- (green detector)
color_map(3) = blue_mean - 0.5 * (red_mean + green_mean);
                                       % Blue+/Yellow- (blue detector)
color_map(4) = 0.5 * (red_mean + green_mean) - blue_mean;
                                       % Yellow+/Blue- (yellow detector)
for k = 1:4
    if (color_map(k) < 0)
        color_map(k) = 0;
    end;
end;

% Set the display to what's there behind the camera.
disp_scene = whole_scene;

% Draw camera boundaries.
for xx = camera_left_b : camera_right_b
    disp_scene(camera_top_b, xx, 1) = 1.0;
    disp_scene(camera_top_b, xx, 2) = 1.0;
    disp_scene(camera_top_b, xx, 3) = 1.0;    
    disp_scene(camera_bottom_b, xx, 1) = 1.0;
    disp_scene(camera_bottom_b, xx, 2) = 1.0;
    disp_scene(camera_bottom_b, xx, 3) = 1.0;
end;
for yy = camera_top_b : camera_bottom_b
    disp_scene(yy, camera_left_b, 1) = 1.0;
    disp_scene(yy, camera_left_b, 2) = 1.0;
    disp_scene(yy, camera_left_b, 3) = 1.0;
    disp_scene(yy, camera_right_b, 1) = 1.0;
    disp_scene(yy, camera_right_b, 2) = 1.0;
    disp_scene(yy, camera_right_b, 3) = 1.0;
end;

% Draw fovea boundaries.
for xx = fovea_left_b : fovea_right_b
    disp_scene(fovea_top_b, xx, 1) = 1.0;
    disp_scene(fovea_top_b, xx, 2) = 1.0;
    disp_scene(fovea_top_b, xx, 3) = 1.0;
    disp_scene(fovea_bottom_b, xx, 1) = 1.0;
    disp_scene(fovea_bottom_b, xx, 2) = 1.0;
    disp_scene(fovea_bottom_b, xx, 3) = 1.0;
end;
for yy = fovea_top_b : fovea_bottom_b
    disp_scene(yy, fovea_left_b, 1) = 1.0;
    disp_scene(yy, fovea_left_b, 2) = 1.0;
    disp_scene(yy, fovea_left_b, 3) = 1.0;
    disp_scene(yy, fovea_right_b, 1) = 1.0;
    disp_scene(yy, fovea_right_b, 2) = 1.0;
    disp_scene(yy, fovea_right_b, 3) = 1.0;
end;
 
% Update the iteration count label.
iter_str = ['Iteration #',num2str(iter)];
set(iter_label,'String',iter_str);

% Draw the environment and camaera.
figtitle = strcat('Iteration #',num2str(iter));
set(fh, 'Name', figtitle);
plot_id = 1;
if (subplot_inds(plot_id,3) > 0)
    axes(env_axes);
    set(env_im,'CData',disp_scene);
end;

% Draw the perifoveal view.
plot_id = 2;
if (subplot_inds(plot_id,3) > 0)
    axes(perifov_axes);
    set(perifov_im,'CData',retina_rods);
end;

% Draw the motor exec units.
plot_id = 3;
if (subplot_inds(plot_id,3) > 0)
    motor_units = zeros(3,1);
    if (brain_type == brain_cog_model)
        area_ind = TrackExec_ind; 
        fetchps_area_activs_iter; 
        motor_units(1) = activs;
        area_ind = NodExec_ind; 
        fetchps_area_activs_iter;     
        motor_units(2) = activs;
        area_ind = ShakeExec_ind; 
        fetchps_area_activs_iter;       
        motor_units(3) = activs;
    else
        motor_units(1) = track_execute;
        motor_units(2) = nod_execute;
        motor_units(3) = shake_execute;
    end;
    axes(motor_exec_axes);
    set(motor_exec_im,'CData',motor_units);
end;

% Draw the color input units.
plot_id = 4;
if (subplot_inds(plot_id,3) > 0)
    axes(color_input_axes);
    if (brain_type == brain_cog_model)
        area_ind = ColorIn_ind; 
        fetchps_area_activs_iter;
        set(color_input_im,'CData',[activs mem_color_map]);
    else
        set(color_input_im,'CData',[color_map mem_color_map]);      
    end;
end;

% Draw the tone input units.
plot_id = 5;
if (subplot_inds(plot_id,3) > 0)
    axes(tones_input_axes);
    if (brain_type == brain_cog_model)
        area_ind = TonesIn_ind; 
        fetchps_area_activs_iter; 
        set(tones_input_im,'CData',[activs mem_tones_map]);
    else 
        set(tones_input_im,'CData',[tones_on mem_tones_map]); 
    end;
end;

% Draw the reward unit.
plot_id = 6;
if (subplot_inds(plot_id,3) > 0)
    rew_pun_units = zeros(2,1);
    axes(rew_pun_input_axes);
    if (brain_type == brain_cog_model)
        area_ind = RewardIn_ind;
        fetchps_area_activs_iter;        
        rew_pun_units(1) = activs;
        area_ind = PunisherIn_ind;
        fetchps_area_activs_iter;         
        rew_pun_units(2) = activs;
        set(rew_pun_input_im,'CData',rew_pun_units);
    else     
        rew_pun_units(1) = reward_on;
        rew_pun_units(2) = punish_on;
        set(rew_pun_input_im,'CData',rew_pun_units);
    end;
end;

% If we're displaying brain information...
if (brain_type == brain_cog_model)
    % Draw the novelty unit.
    plot_id = 7;    
    if (subplot_inds(plot_id,3) > 0)
        axes(novelty_axes);
        area_ind = Novelty_ind; 
        fetchps_area_activs_iter; 
        set(novelty_im,'CData',activs);   
    end;
    
    % Draw the visual stimulus presence unit.
    plot_id = 8; 
    if (subplot_inds(plot_id,3) > 0)
        axes(vispres_axes);
        area_ind = VisStimOn_ind; 
        fetchps_area_activs_iter;
        set(vispres_im,'CData',activs);   
    end;  
      
    % Draw the reward cue unit.
    plot_id = 9;
    if (subplot_inds(plot_id,3) > 0)
        axes(reward_cue_axes);
        area_ind = RewardCue_ind; 
        fetchps_area_activs_iter;
        set(reward_cue_im,'CData',activs);   
    end;
    
    % Draw the reward prediction unit.
    plot_id = 10;   
    
    % Draw the DA signal unit.
    plot_id = 11;
    if (subplot_inds(plot_id,3) > 0)
        axes(DA_signal_axes);
        area_ind = DASignal_ind; 
        fetchps_area_activs_iter; 
        set(DA_signal_im,'CData',activs);   
    end;
 
    % Draw the frustration unit.
    plot_id = 12;   
    if (subplot_inds(plot_id,3) > 0)
        axes(frust_axes);
        area_ind = Frustration_ind; 
        fetchps_area_activs_iter; 
        set(frust_im,'CData',activs);   
    end;
    
    % Draw babble gating unit activity.
    plot_id = 13;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_gate_level_axes);
        babble_gate_units = zeros(2,3);
        area_ind = BabbleReq_ind; 
        fetchps_area_activs_iter; 
        babble_gate_units(1,1) = activs;          
        area_ind = BabbleNoGo_ind; 
        fetchps_area_activs_iter;     
        babble_gate_units(2,1) = sum(sum(activs));       
        area_ind = BabbleGoE_ind; 
        fetchps_area_activs_iter; 
        babble_gate_units(1,2) = sum(sum(activs));     
        area_ind = BabbleGoI_ind; 
        fetchps_area_activs_iter;  
        babble_gate_units(2,2) = sum(sum(activs));               
        area_ind = BabbleInit_ind; 
        fetchps_area_activs_iter; 
        babble_gate_units(1,3) = activs;    
        area_ind = BabbleExec_ind; 
        fetchps_area_activs_iter; 
        babble_gate_units(2,3) = activs;    
        set(babble_gate_level_im,'CData',babble_gate_units);   
    end; 
    
    % Draw the Babble Request unit.
    plot_id = 14;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_req_axes);
        area_ind = BabbleReq_ind; 
        fetchps_area_activs_iter;
        set(babble_req_im,'CData',activs);   
    end;     
    
    % Draw the Babble Go excitatory units.
    plot_id = 15;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_go_e_units_axes);
%         area_ind = BabbleGoE_ind; 
%         fetchps_area_activs_iter; 
        activs = S(babble_go_e_units_uinds);          
        set(babble_go_e_units_im,'CData',activs);   
    end;
    
    % Draw the Babble Go inhibitory units.
    plot_id = 16;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_go_i_units_axes);
%         area_ind = BabbleGoI_ind; 
%         fetchps_area_activs_iter; 
        activs = S(babble_go_i_units_uinds);          
        set(babble_go_i_units_im,'CData',activs);   
    end;  
    
    % Draw the Babble NoGo units.
    plot_id = 17;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_nogo_units_axes);
        area_ind = BabbleNoGo_ind; 
        fetchps_area_activs_iter; 
        set(babble_nogo_units_im,'CData',activs);   
    end;    
    
    % Draw the Babble Init unit.
    plot_id = 18;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_init_axes);
        area_ind = BabbleInit_ind; 
        fetchps_area_activs_iter;
        set(babble_init_im,'CData',activs);   
    end;     
        
    % Draw babble units.
    plot_id = 19;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_units_axes);
        area_ind = Babble_ind;        
        fetchps_area_activs_iter; 
        set(babble_units_im,'CData',activs); 
    end;
    
    % Draw the plan units.
    plot_id = 20;
    if (subplot_inds(plot_id,3) > 0)
        axes(plan_units_axes);
        area_ind = Plan_ind; 
        fetchps_area_activs_iter; 
        set(plan_units_im,'CData',activs);   
    end;

    % Draw the motor gating units.
    plot_id = 21;
    if (subplot_inds(plot_id,3) > 0)
        axes(motor_gate_axes);  
        motor_gate_units = zeros(4,4);  
        area_ind = NodShakeConf_ind; 
        fetchps_area_activs_iter;  
        motor_gate_units(2,1) = activs;     
        area_ind = NodReqE_ind; 
        fetchps_area_activs_iter;  
        motor_gate_units(1,1) = sum(sum(activs));      
        area_ind = NodGoE_ind; 
        fetchps_area_activs_iter; 
        motor_gate_units(1,2) = sum(sum(activs));       
        area_ind = NodGoI_ind; 
        fetchps_area_activs_iter;  
        motor_gate_units(2,2) = sum(sum(activs));       
        area_ind = NodNoGo_ind; 
        fetchps_area_activs_iter;     
        motor_gate_units(2,3) = sum(sum(activs));        
        area_ind = NodInit_ind; 
        fetchps_area_activs_iter;  
        motor_gate_units(1,4) = activs;
        area_ind = NodExec_ind; 
        fetchps_area_activs_iter;     
        motor_gate_units(2,4) = activs;    
        area_ind = ShakeReqE_ind; 
        fetchps_area_activs_iter;     
        motor_gate_units(3,1) = sum(sum(activs));      
        area_ind = ShakeGoE_ind; 
        fetchps_area_activs_iter;     
        motor_gate_units(3,2) = sum(sum(activs));
        area_ind = ShakeGoI_ind; 
        fetchps_area_activs_iter;     
        motor_gate_units(4,2) = sum(sum(activs));  
        area_ind = ShakeNoGo_ind; 
        fetchps_area_activs_iter;       
        motor_gate_units(4,3) = sum(sum(activs));   
        area_ind = ShakeInit_ind; 
        fetchps_area_activs_iter;     
        motor_gate_units(3,4) = sum(sum(activs));
        area_ind = ShakeExec_ind; 
        fetchps_area_activs_iter;       
        motor_gate_units(4,4) = activs;          
        set(motor_gate_im,'CData',motor_gate_units);   
    end;   
    
    % Draw the Nod Request excitatory unit.
    plot_id = 22;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_req_e_axes);
        area_ind = NodReqE_ind; 
        fetchps_area_activs_iter;
        set(nod_req_e_im,'CData',activs);   
    end;  
    
    % Draw the Nod Request inhibitory unit.
    plot_id = 23;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_req_i_axes);
        area_ind = NodReqI_ind; 
        fetchps_area_activs_iter;
        set(nod_req_i_im,'CData',activs);   
    end;     
   
    % Draw the Nod Go excitatory units.
    plot_id = 24;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_go_e_units_axes);
%         area_ind = NodGoE_ind; 
%         fetchps_area_activs_iter; 
        activs = S(nod_go_e_units_uinds);          
        set(nod_go_e_units_im,'CData',activs);   
    end;
    
    % Draw the Nod Go inhibitory units.
    plot_id = 25;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_go_i_units_axes);
%         area_ind = NodGoI_ind; 
%         fetchps_area_activs_iter; 
        activs = S(nod_go_i_units_uinds);          
        set(nod_go_i_units_im,'CData',activs);   
    end;    

    % Draw the Nod NoGo units.
    plot_id = 26;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_nogo_units_axes);
        area_ind = NodNoGo_ind; 
        fetchps_area_activs_iter; 
        set(nod_nogo_units_im,'CData',activs);   
    end;    
      
    % Draw the Nod Init unit.
    plot_id = 27;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_init_axes);
        area_ind = NodInit_ind; 
        fetchps_area_activs_iter;
        set(nod_init_im,'CData',activs);   
    end;      
        
    % Draw the Shake Request excitatory unit.
    plot_id = 28;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_req_e_axes);
        area_ind = ShakeReqE_ind; 
        fetchps_area_activs_iter;
        set(shake_req_e_im,'CData',activs);   
    end;  
    
    % Draw the Shake Request inhibitory unit.
    plot_id = 29;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_req_i_axes);
        area_ind = ShakeReqI_ind; 
        fetchps_area_activs_iter;
        set(shake_req_i_im,'CData',activs);   
    end;      
    
    % Draw the Shake Go excitatory units.
    plot_id = 30;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_go_e_units_axes);
        area_ind = ShakeGoE_ind; 
        fetchps_area_activs_iter; 
        set(shake_go_e_units_im,'CData',activs);   
    end;
    
    % Draw the Shake Go inhibitory units.
    plot_id = 31;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_go_i_units_axes);
        area_ind = ShakeGoI_ind; 
        fetchps_area_activs_iter; 
        set(shake_go_i_units_im,'CData',activs);   
    end;        
    
    % Draw the Shake NoGo units.
    plot_id = 32;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_nogo_units_axes);
        area_ind = ShakeNoGo_ind; 
        fetchps_area_activs_iter; 
        set(shake_nogo_units_im,'CData',activs);   
    end; 

    % Draw the Shake Init unit.
    plot_id = 33;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_init_axes);
        area_ind = ShakeInit_ind; 
        fetchps_area_activs_iter;
        set(shake_init_im,'CData',activs);   
    end; 
   
    % Draw neural noise units.
    plot_id = 34;
    if (subplot_inds(plot_id,3) > 0)
        axes(neural_noise_units_axes);
        area_ind = NeuralNoise_ind; 
        fetchps_area_activs_iter; 
        set(neural_noise_units_im,'CData',activs); 
    end;
  
    % Draw neural dice units.
    plot_id = 35;
    if (subplot_inds(plot_id,3) > 0)
        axes(neural_dice_units_axes);        
%         area_ind = NeuralDiceE_ind; 
%         fetchps_area_activs_iter; 
        activs = S(neural_dice_units_uinds);        
        set(neural_dice_units_im,'CData',activs); 
    end;
    
    % Draw neural geted dice units.
    plot_id = 36;
    if (subplot_inds(plot_id,3) > 0)
        axes(neural_gated_dice_units_axes);
        area_ind = GatedDice_ind; 
        fetchps_area_activs_iter; 
        set(neural_gated_dice_units_im,'CData',activs); 
    end;
    
    % Draw the Neural Dice Set Init unit.
    plot_id = 37;
    if (subplot_inds(plot_id,3) > 0)
        axes(neural_dice_set_axes);
        area_ind = DiceSet_ind; 
        fetchps_area_activs_iter;
        set(neural_dice_set_im,'CData',activs);   
    end; 
    
    % Draw the Neural Dice Gate Init unit.
    plot_id = 38;
    if (subplot_inds(plot_id,3) > 0)
        axes(neural_dice_gate_axes);
        area_ind = DiceGate_ind; 
        fetchps_area_activs_iter;
        set(neural_dice_gate_im,'CData',activs);   
    end;     
    
    % Draw the Nod Request -> Nod Go fanout weights.
    plot_id = 39;    
    if (subplot_inds(plot_id,3) > 0)
        axes(nodreq_nodgo_wts_axes);       
%         fasc_ind = NodReqtoGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter;         
        if (nodreq_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(nodreq_nodgo_wts_winds));
        else
            wts = CW(nodreq_nodgo_wts_winds);
        end;
        set(nodreq_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Nod Go fanout weights.
    plot_id = 40;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_nodgo_wts_axes);    
%         fasc_ind = Color_WMtoNGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (redWM_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(redWM_nodgo_wts_winds));
        else
            wts = CW(redWM_nodgo_wts_winds);
        end;        
        set(redWM_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Nod Go fanout weights.
    plot_id = 41;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_nodgo_wts_axes);
%         fasc_ind = Color_WMtoNGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 2;
%         fetchps_cell_wts_iter; 
        if (greenWM_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(greenWM_nodgo_wts_winds));
        else
            wts = CW(greenWM_nodgo_wts_winds);
        end;           
        set(greenWM_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Nod Go fanout weights.
    plot_id = 42;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_nodgo_wts_axes);
%         fasc_ind = Color_WMtoNGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 3;
%         fetchps_cell_wts_iter; 
        if (blueWM_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(blueWM_nodgo_wts_winds));
        else
            wts = CW(blueWM_nodgo_wts_winds);
        end;               
        set(blueWM_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the YellowWM -> Nod Go fanout weights.
    plot_id = 43;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_nodgo_wts_axes);
%         fasc_ind = Color_WMtoNGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 4;
%         fetchps_cell_wts_iter; 
        if (yellowWM_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(yellowWM_nodgo_wts_winds));
        else
            wts = CW(yellowWM_nodgo_wts_winds);
        end;                
        set(yellowWM_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the CToneWM -> Nod Go fanout weights.
    plot_id = 44;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_nodgo_wts_axes);
%         fasc_ind = Tones_WMtoNGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (c_toneWM_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(c_toneWM_nodgo_wts_winds));
        else
            wts = CW(c_toneWM_nodgo_wts_winds);
        end;          
        set(c_toneWM_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Nod Go fanout weights.
    plot_id = 45;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_nodgo_wts_axes);
%         fasc_ind = Tones_WMtoNGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 4;
%         fetchps_cell_wts_iter; 
        if (eflat_toneWM_nodgo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(eflat_toneWM_nodgo_wts_winds));
        else
            wts = CW(eflat_toneWM_nodgo_wts_winds);
        end;         
        set(eflat_toneWM_nodgo_wts_im,'CData',wts);   
    end; 
    
    % Draw the Nod Init -> Nod NoGo fanout weights.
    plot_id = 46;    
    if (subplot_inds(plot_id,3) > 0)
        axes(nodinit_nodnogo_wts_axes);
%         fasc_ind = NodInittoNoGo_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (nodinit_nodnogo_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(nodinit_nodnogo_wts_winds));
        else
            wts = CW(nodinit_nodnogo_wts_winds);
        end;        
        set(nodinit_nodnogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Nod NoGo fanout weights.
    plot_id = 47;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_nodnogo_wts_axes);
        fasc_ind = Color_WMtoNNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(redWM_nodnogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Nod NoGo fanout weights.
    plot_id = 48;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_nodnogo_wts_axes);
        fasc_ind = Color_WMtoNNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetchps_cell_wts_iter; 
        
        set(greenWM_nodnogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Nod NoGo fanout weights.
    plot_id = 49;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_nodnogo_wts_axes);
        fasc_ind = Color_WMtoNNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetchps_cell_wts_iter; 
        
        set(blueWM_nodnogo_wts_im,'CData',wts);   
    end;   
    
    % Draw the YellowWM -> Nod NoGo fanout weights.
    plot_id = 50;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_nodnogo_wts_axes);
        fasc_ind = Color_WMtoNNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(yellowWM_nodnogo_wts_im,'CData',wts);   
    end;
    
    % Draw the CToneWM -> Nod NoGo fanout weights.
    plot_id = 51;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_nodnogo_wts_axes);
        fasc_ind = Tones_WMtoNNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(c_toneWM_nodnogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Nod NoGo fanout weights.
    plot_id = 52;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_nodnogo_wts_axes);
        fasc_ind = Tones_WMtoNNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(eflat_toneWM_nodnogo_wts_im,'CData',wts);   
    end;   
       
    % Draw the Shake Request -> Shake Go fanout weights.
    plot_id = 53;    
    if (subplot_inds(plot_id,3) > 0)
        axes(shakereq_shakego_wts_axes);
        fasc_ind = ShakeReqtoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(shakereq_shakego_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Shake Go fanout weights.
    plot_id = 54;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_shakego_wts_axes);
        fasc_ind = Color_WMtoSGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(redWM_shakego_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Shake Go fanout weights.
    plot_id = 55;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_shakego_wts_axes);
        fasc_ind = Color_WMtoSGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetchps_cell_wts_iter; 
        
        set(greenWM_shakego_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Shake Go fanout weights.
    plot_id = 56;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_shakego_wts_axes);
        fasc_ind = Color_WMtoSGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetchps_cell_wts_iter; 
        
        set(blueWM_shakego_wts_im,'CData',wts);   
    end; 
    
    % Draw the YellowWM -> Shake Go fanout weights.
    plot_id = 57;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_shakego_wts_axes);
        fasc_ind = Color_WMtoSGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(yellowWM_shakego_wts_im,'CData',wts);   
    end; 
    
    % Draw the CToneWM -> Shake Go fanout weights.
    plot_id = 58;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_shakego_wts_axes);
        fasc_ind = Tones_WMtoSGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(c_toneWM_shakego_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Shake Go fanout weights.
    plot_id = 59;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_shakego_wts_axes);
        fasc_ind = Tones_WMtoSGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(eflat_toneWM_shakego_wts_im,'CData',wts);   
    end; 
       
    % Draw the Shake Init -> Shake NoGo fanout weights.
    plot_id = 60;    
    if (subplot_inds(plot_id,3) > 0)
        axes(shakeinit_shakenogo_wts_axes);
        fasc_ind = ShakeInittoNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(shakeinit_shakenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Shake NoGo fanout weights.
    plot_id = 61;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_shakenogo_wts_axes);
        fasc_ind = Color_WMtoSNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(redWM_shakenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Shake NoGo fanout weights.
    plot_id = 62;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_shakenogo_wts_axes);
        fasc_ind = Color_WMtoSNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetchps_cell_wts_iter; 
        
        set(greenWM_shakenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Shake NoGo fanout weights.
    plot_id = 63;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_shakenogo_wts_axes);
        fasc_ind = Color_WMtoSNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetchps_cell_wts_iter; 
        
        set(blueWM_shakenogo_wts_im,'CData',wts);   
    end;   
    
    % Draw the YellowWM -> Shake NoGo fanout weights.
    plot_id = 64;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_shakenogo_wts_axes);
        fasc_ind = Color_WMtoSNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(yellowWM_shakenogo_wts_im,'CData',wts);   
    end;
    
    % Draw the CToneWM -> Shake NoGo fanout weights.
    plot_id = 65;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_shakenogo_wts_axes);
        fasc_ind = Tones_WMtoSNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(c_toneWM_shakenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Shake NoGo fanout weights.
    plot_id = 66;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_shakenogo_wts_axes);
        fasc_ind = Tones_WMtoSNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(eflat_toneWM_shakenogo_wts_im,'CData',wts);   
    end; 
 
    % Draw the Babble Request -> Babble Go fanout weights.
    plot_id = 67;    
    if (subplot_inds(plot_id,3) > 0)
        axes(babblereq_babblego_wts_axes);
        fasc_ind = BabbleReqtoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(babblereq_babblego_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Babble Go fanout weights.
    plot_id = 68;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_babblego_wts_axes);
        fasc_ind = Color_WMtoBGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(redWM_babblego_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Babble Go fanout weights.
    plot_id = 69;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_babblego_wts_axes);
        fasc_ind = Color_WMtoBGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetchps_cell_wts_iter; 
        
        set(greenWM_babblego_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Babble Go fanout weights.
    plot_id = 70;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_babblego_wts_axes);
        fasc_ind = Color_WMtoBGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetchps_cell_wts_iter; 
        
        set(blueWM_babblego_wts_im,'CData',wts);   
    end; 
    
    % Draw the YellowWM -> Babble Go fanout weights.
    plot_id = 71;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_babblego_wts_axes);
        fasc_ind = Color_WMtoBGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(yellowWM_babblego_wts_im,'CData',wts);   
    end; 
    
    % Draw the CToneWM -> Babble Go fanout weights.
    plot_id = 72;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_babblego_wts_axes);
        fasc_ind = Tones_WMtoBGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(c_toneWM_babblego_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Babble Go fanout weights.
    plot_id = 73;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_babblego_wts_axes);
        fasc_ind = Tones_WMtoBGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(eflat_toneWM_babblego_wts_im,'CData',wts);   
    end; 
       
    % Draw the Babble Init -> Babble NoGo fanout weights.
    plot_id = 74;    
    if (subplot_inds(plot_id,3) > 0)
        axes(babbleinit_babblenogo_wts_axes);
        fasc_ind = BabbleInittoNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(babbleinit_babblenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Babble NoGo fanout weights.
    plot_id = 75;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_babblenogo_wts_axes);
        fasc_ind = Color_WMtoBNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(redWM_babblenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Babble NoGo fanout weights.
    plot_id = 76;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_babblenogo_wts_axes);
        fasc_ind = Color_WMtoBNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 2;
        fetchps_cell_wts_iter; 
        
        set(greenWM_babblenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Babble NoGo fanout weights.
    plot_id = 77;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_babblenogo_wts_axes);
        fasc_ind = Color_WMtoBNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 3;
        fetchps_cell_wts_iter; 
        
        set(blueWM_babblenogo_wts_im,'CData',wts);   
    end;   
    
    % Draw the YellowWM -> Babble NoGo fanout weights.
    plot_id = 78;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_babblenogo_wts_axes);
        fasc_ind = Color_WMtoBNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(yellowWM_babblenogo_wts_im,'CData',wts);   
    end;
    
    % Draw the CToneWM -> Babble NoGo fanout weights.
    plot_id = 79;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_babblenogo_wts_axes);
        fasc_ind = Tones_WMtoBNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 1;
        fetchps_cell_wts_iter; 
        
        set(c_toneWM_babblenogo_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Babble NoGo fanout weights.
    plot_id = 80;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_babblenogo_wts_axes);
        fasc_ind = Tones_WMtoBNoGo_ind; 
        fanin = 0;
        x_ind = 1;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        
        set(eflat_toneWM_babblenogo_wts_im,'CData',wts);   
    end; 

    % Draw the VisStim -> Plan fanout weights.
    plot_id = 81;    
    if (subplot_inds(plot_id,3) > 0)
        axes(vispres_plan_wts_axes);
%         fasc_ind = VisStimtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter;        
        if (vispres_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(vispres_plan_wts_winds));
        else
            wts = CW(vispres_plan_wts_winds);
        end;   
        set(vispres_plan_wts_im,'CData',wts);   
    end; 
    
    % Draw the RedWM -> Plan fanout weights.
    plot_id = 82;
    if (subplot_inds(plot_id,3) > 0)
        axes(redWM_plan_wts_axes);
%         fasc_ind = Color_WMtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (redWM_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(redWM_plan_wts_winds));
        else
            wts = CW(redWM_plan_wts_winds);
        end;          
        set(redWM_plan_wts_im,'CData',wts);   
    end; 
    
    % Draw the GreenWM -> Plan fanout weights.
    plot_id = 83;
    if (subplot_inds(plot_id,3) > 0)
        axes(greenWM_plan_wts_axes);
%         fasc_ind = Color_WMtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 2;
%         fetchps_cell_wts_iter; 
        if (greenWM_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(greenWM_plan_wts_winds));
        else
            wts = CW(greenWM_plan_wts_winds);
        end;         
        set(greenWM_plan_wts_im,'CData',wts);   
    end; 
    
    % Draw the BlueWM -> Plan fanout weights.
    plot_id = 84;
    if (subplot_inds(plot_id,3) > 0)
        axes(blueWM_plan_wts_axes);
%         fasc_ind = Color_WMtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 3;
%         fetchps_cell_wts_iter; 
        if (blueWM_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(blueWM_plan_wts_winds));
        else
            wts = CW(blueWM_plan_wts_winds);
        end;         
        set(blueWM_plan_wts_im,'CData',wts);   
    end; 
    
    % Draw the YellowWM -> Plan fanout weights.
    plot_id = 85;
    if (subplot_inds(plot_id,3) > 0)
        axes(yellowWM_plan_wts_axes);
%         fasc_ind = Color_WMtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 4;
%         fetchps_cell_wts_iter; 
        if (yellowWM_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(yellowWM_plan_wts_winds));
        else
            wts = CW(yellowWM_plan_wts_winds);
        end;         
        set(yellowWM_plan_wts_im,'CData',wts);   
    end; 
    
    % Draw the CToneWM -> Plan fanout weights.
    plot_id = 86;
    if (subplot_inds(plot_id,3) > 0)
        axes(c_toneWM_plan_wts_axes);
%         fasc_ind = Tones_WMtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (c_toneWM_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(c_toneWM_plan_wts_winds));
        else
            wts = CW(c_toneWM_plan_wts_winds);
        end;         
        set(c_toneWM_plan_wts_im,'CData',wts);   
    end; 
    
    % Draw the EFlatToneWM -> Plan fanout weights.
    plot_id = 87;
    if (subplot_inds(plot_id,3) > 0)
        axes(eflat_toneWM_plan_wts_axes);
%         fasc_ind = Tones_WMtoPlan_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 4;
%         fetchps_cell_wts_iter; 
        if (eflat_toneWM_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(eflat_toneWM_plan_wts_winds));
        else
            wts = CW(eflat_toneWM_plan_wts_winds);
        end;         
        set(eflat_toneWM_plan_wts_im,'CData',wts);   
    end;  

    % Draw the Bias -> Plan fanout weights.
    plot_id = 88;
    if (subplot_inds(plot_id,3) > 0)
        axes(bias_plan_wts_axes);
%         fasc_ind = PlanBias_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (bias_plan_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(bias_plan_wts_winds));
        else
            wts = CW(bias_plan_wts_winds);
        end;         
        set(bias_plan_wts_im,'CData',wts);   
    end;    
   
    % Draw the Bias -> Nod Request fanout weights.
    plot_id = 89;
    if (subplot_inds(plot_id,3) > 0)
        axes(bias_nodreq_wts_axes);
%         fasc_ind = NodReqBias_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (bias_nodreq_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(bias_nodreq_wts_winds));
        else
            wts = CW(bias_nodreq_wts_winds);
        end;         
        set(bias_nodreq_wts_im,'CData',wts);   
    end;  
    
    % Draw the Bias -> Shake Request fanout weights.
    plot_id = 90;
    if (subplot_inds(plot_id,3) > 0)
        axes(bias_shakereq_wts_axes);
%         fasc_ind = ShakeReqBias_ind; 
%         fanin = 0;
%         x_ind = 1;
%         y_ind = 1;
%         fetchps_cell_wts_iter; 
        if (bias_shakereq_wts_mod == 1)
            wts = modCWcurr(Cmdc_ind(bias_shakereq_wts_winds));
        else
            wts = CW(bias_shakereq_wts_winds);
        end;         
        set(bias_shakereq_wts_im,'CData',wts);   
    end;  
    
    % Draw the Inputs -> Plan fanin weights.
    plot_id = 91;    
    if (subplot_inds(plot_id,3) > 0)
        axes(plan_fanin_axes);  
        plan_fanin_wts = zeros(4,5);       
        fasc_ind = VisStimtoPlanE_ind; 
        fanin = 1;
        x_ind = 5;
        y_ind = 4;
        fetchps_cell_wts_iter; 
        plan_fanin_wts(1,1) = wts;
        fasc_ind = Color_WMtoPlanE_ind; 
        fetchps_cell_wts_iter; 
        plan_fanin_wts(:,2) = wts;
        fasc_ind = Tones_WMtoPlanE_ind; 
        fetchps_cell_wts_iter; 
        plan_fanin_wts(:,3) = wts(1:4); 
        plan_fanin_wts(:,4) = wts(5:8);
        plan_fanin_wts(:,5) = wts(9:12);
        set(plan_fanin_im,'CData',plan_fanin_wts);   
    end;    
    
    % Draw Nod Init -> Nod NoGo fascicle summed net input sums.
    plot_id = 92;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_init_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = nod_init_nogo_fascins_data(:,:,time_ind);
        else
            area_ind = NodNoGo_ind;
            fasc_ind = NodInittoNoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(nod_init_nogo_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Neural DiceE -> Nod NoGo fascicle summed net input sums.
    plot_id = 93;
    if (subplot_inds(plot_id,3) > 0)
        axes(dice_nod_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = dice_nod_nogo_fascins_data(:,:,time_ind);
        else
            area_ind = NodNoGo_ind;
            fasc_ind = TNoisetoNNoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(dice_nod_nogo_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Color and Tone WM -> Nod NoGo fascicle summed net input sums.
    plot_id = 94;
    if (subplot_inds(plot_id,3) > 0)
        axes(wm_nod_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = color_wm_nod_nogo_fascins_data(:,:,time_ind);
            fascins2 = tones_wm_nod_nogo_fascins_data(:,:,time_ind); 
        else
            area_ind = NodNoGo_ind;
            fasc_ind = Color_WMtoNNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;
            fasc_ind = Tones_WMtoNNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;  
        end;
        set(wm_nod_nogo_fascins_im,'CData',fascins1+fascins2);   
    end; 
    
    % Draw otal Nod NoGo fascicle summed net input sums.
    plot_id = 95;
    if (subplot_inds(plot_id,3) > 0)
        axes(tot_nod_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = nod_init_nogo_fascins_data(:,:,time_ind);
            fascins2 = dice_nod_nogo_fascins_data(:,:,time_ind);
            fascins3 = color_wm_nod_nogo_fascins_data(:,:,time_ind);
            fascins4 = tones_wm_nod_nogo_fascins_data(:,:,time_ind);  
        else
            area_ind = NodNoGo_ind;      
            fasc_ind = NodInittoNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = TNoisetoNNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Color_WMtoNNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = Tones_WMtoNNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins;  
        end;
        set(tot_nod_nogo_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4);   
    end; 
   
    % Draw Shake Init -> Shake NoGo fascicle summed net input sums.
    plot_id = 96;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_init_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = shake_init_nogo_fascins_data(:,:,time_ind);
        else
            area_ind = ShakeNoGo_ind;
            fasc_ind = ShakeInittoNoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(shake_init_nogo_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Neural DiceE -> Shake NoGo fascicle summed net input sums.
    plot_id = 97;
    if (subplot_inds(plot_id,3) > 0)
        axes(dice_shake_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = dice_shake_nogo_fascins_data(:,:,time_ind);
        else
            area_ind = ShakeNoGo_ind;
            fasc_ind = TNoisetoSNoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(dice_shake_nogo_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Color and Tone WM -> Shake NoGo fascicle summed net input sums.
    plot_id = 98;
    if (subplot_inds(plot_id,3) > 0)
        axes(wm_shake_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = color_wm_shake_nogo_fascins_data(:,:,time_ind);
            fascins2 = tones_wm_shake_nogo_fascins_data(:,:,time_ind); 
        else
            area_ind = ShakeNoGo_ind;
            fasc_ind = Color_WMtoSNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;
            fasc_ind = Tones_WMtoSNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;  
        end;
        set(wm_shake_nogo_fascins_im,'CData',fascins1+fascins2);   
    end; 
    
    % Draw Total Shake NoGo fascicle summed net input sums.
    plot_id = 99;
    if (subplot_inds(plot_id,3) > 0)
        axes(tot_shake_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = shake_init_nogo_fascins_data(:,:,time_ind);
            fascins2 = dice_shake_nogo_fascins_data(:,:,time_ind);
            fascins3 = color_wm_shake_nogo_fascins_data(:,:,time_ind);
            fascins4 = tones_wm_shake_nogo_fascins_data(:,:,time_ind);  
        else
            area_ind = ShakeNoGo_ind;      
            fasc_ind = ShakeInittoNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = TNoisetoSNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Color_WMtoSNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = Tones_WMtoSNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins;  
        end;
        set(tot_shake_nogo_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4);   
    end;     
    
    % Draw Nod Request -> Nod Go fascicle summed net input sums.
    plot_id = 100;
    if (subplot_inds(plot_id,3) > 0)
        axes(nod_req_go_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = nod_req_go_fascins_data(:,:,time_ind);
        else
            area_ind = NodGoE_ind;
            fasc_ind = NodReqtoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(nod_req_go_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Neural DiceE -> Nod Go fascicle summed net input sums.
    plot_id = 101;
    if (subplot_inds(plot_id,3) > 0)
        axes(dice_nod_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins = dice_nod_go_fascins_data(:,:,time_ind);
        else
            area_ind = NodGoE_ind;
            fasc_ind = TNoisetoNGo_ind; 
            fetchps_area_fascin_iter;  
        end;  
        set(dice_nod_go_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Color and Tone WM -> Nod Go fascicle summed net input sums.
    plot_id = 102;
    if (subplot_inds(plot_id,3) > 0)
        axes(wm_nod_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins1 = color_wm_nod_go_fascins_data(:,:,time_ind);
            fascins2 = tones_wm_nod_go_fascins_data(:,:,time_ind);            
        else
            area_ind = NodGoE_ind;
            fasc_ind = Color_WMtoNGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;
            fasc_ind = Tones_WMtoNGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins; 
        end;
        set(wm_nod_go_fascins_im,'CData',fascins1+fascins2);   
    end; 
    
    % Draw Total Nod Go fascicle summed net input sums.
    plot_id = 103;
    if (subplot_inds(plot_id,3) > 0)
        axes(tot_nod_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins1 = nod_req_go_fascins_data(:,:,time_ind);
            fascins2 = dice_nod_go_fascins_data(:,:,time_ind);
            fascins3 = color_wm_nod_go_fascins_data(:,:,time_ind);
            fascins4 = tones_wm_nod_go_fascins_data(:,:,time_ind);          
        else
            area_ind = NodGoE_ind;      
            fasc_ind = NodReqtoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = TNoisetoNGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Color_WMtoNGo_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = Tones_WMtoNGo_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins; 
        end;
        set(tot_nod_go_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4);   
    end; 
   
    % Draw Shake Request -> Shake Go fascicle summed net input sums.
    plot_id = 104;
    if (subplot_inds(plot_id,3) > 0)
        axes(shake_req_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins = shake_req_go_fascins_data(:,:,time_ind);
        else
            area_ind = ShakeGoE_ind;
            fasc_ind = ShakeReqtoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(shake_req_go_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Neural DiceE -> Shake Go fascicle summed net input sums.
    plot_id = 105;
    if (subplot_inds(plot_id,3) > 0)
        axes(dice_shake_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins = dice_shake_go_fascins_data(:,:,time_ind);
        else
            area_ind = ShakeGoE_ind;
            fasc_ind = TNoisetoSGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(dice_shake_go_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Color and Tone WM -> Shake Go fascicle summed net input sums.
    plot_id = 106;
    if (subplot_inds(plot_id,3) > 0)
        axes(wm_shake_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins1 = color_wm_shake_go_fascins_data(:,:,time_ind);
            fascins2 = tones_wm_shake_go_fascins_data(:,:,time_ind);   
        else
            area_ind = ShakeGoE_ind;
            fasc_ind = Color_WMtoSGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;
            fasc_ind = Tones_WMtoSGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;  
        end;
        set(wm_shake_go_fascins_im,'CData',fascins1+fascins2);   
    end; 
    
    % Draw otal Shake Go fascicle summed net input sums.
    plot_id = 107;
    if (subplot_inds(plot_id,3) > 0)
        axes(tot_shake_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins1 = shake_req_go_fascins_data(:,:,time_ind);
            fascins2 = dice_shake_go_fascins_data(:,:,time_ind);
            fascins3 = color_wm_shake_go_fascins_data(:,:,time_ind);
            fascins4 = tones_wm_shake_go_fascins_data(:,:,time_ind); 
        else
            area_ind = ShakeGoE_ind;      
            fasc_ind = ShakeReqtoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = TNoisetoSGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Color_WMtoSGo_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = Tones_WMtoSGo_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins;       
        end;
        set(tot_shake_go_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4);   
    end;     
     
    % Draw Babble Request -> Babble Go fascicle summed net input sums.
    plot_id = 108;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_req_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins = babble_req_go_fascins_data(:,:,time_ind);
        else
            area_ind = BabbleGoE_ind;
            fasc_ind = BabbleReqtoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(babble_req_go_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Neural DiceE -> Babble Go fascicle summed net input sums.
    plot_id = 109;
    if (subplot_inds(plot_id,3) > 0)
        axes(dice_babble_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins = dice_babble_go_fascins_data(:,:,time_ind);
        else
            area_ind = BabbleGoE_ind;
            fasc_ind = TNoisetoBGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(dice_babble_go_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Color and Tone WM -> Babble Go fascicle summed net input sums.
    plot_id = 110;
    if (subplot_inds(plot_id,3) > 0)
        axes(wm_babble_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins1 = color_wm_babble_go_fascins_data(:,:,time_ind);
            fascins2 = tones_wm_babble_go_fascins_data(:,:,time_ind);   
        else
            area_ind = BabbleGoE_ind;
            fasc_ind = Color_WMtoBGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;
            fasc_ind = Tones_WMtoBGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;  
        end;
        set(wm_babble_go_fascins_im,'CData',fascins1+fascins2);   
    end; 
    
    % Draw Total Babble Go fascicle summed net input sums.
    plot_id = 111;
    if (subplot_inds(plot_id,3) > 0)
        axes(tot_babble_go_fascins_axes);
        if (do_precalc_fascins == 1) 
            fascins1 = babble_req_go_fascins_data(:,:,time_ind);
            fascins2 = dice_babble_go_fascins_data(:,:,time_ind);
            fascins3 = color_wm_babble_go_fascins_data(:,:,time_ind);
            fascins4 = tones_wm_babble_go_fascins_data(:,:,time_ind); 
        else
            area_ind = BabbleGoE_ind;      
            fasc_ind = BabbleReqtoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = TNoisetoBGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Color_WMtoBGo_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = Tones_WMtoBGo_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins;       
        end;
        set(tot_babble_go_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4);   
    end;         
    
    % Draw Babble Init -> Babble NoGo fascicle summed net input sums.
    plot_id = 112;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_init_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = babble_init_nogo_fascins_data(:,:,time_ind);
        else
            area_ind = BabbleNoGo_ind;
            fasc_ind = BabbleInittoNoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(babble_init_nogo_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Neural DiceE -> Babble NoGo fascicle summed net input sums.
    plot_id = 113;
    if (subplot_inds(plot_id,3) > 0)
        axes(dice_babble_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = dice_babble_nogo_fascins_data(:,:,time_ind);
        else
            area_ind = BabbleNoGo_ind;
            fasc_ind = TNoisetoBNoGo_ind; 
            fetchps_area_fascin_iter;
        end;
        set(dice_babble_nogo_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Color and Tone WM -> Babble NoGo fascicle summed net input sums.
    plot_id = 114;
    if (subplot_inds(plot_id,3) > 0)
        axes(wm_babble_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = color_wm_babble_nogo_fascins_data(:,:,time_ind);
            fascins2 = tones_wm_babble_nogo_fascins_data(:,:,time_ind); 
        else
            area_ind = BabbleNoGo_ind;
            fasc_ind = Color_WMtoBNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;
            fasc_ind = Tones_WMtoBNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;  
        end;
        set(wm_babble_nogo_fascins_im,'CData',fascins1+fascins2);   
    end; 
    
    % Draw Total Babble NoGo fascicle summed net input sums.
    plot_id = 115;
    if (subplot_inds(plot_id,3) > 0)
        axes(tot_babble_nogo_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = babble_init_nogo_fascins_data(:,:,time_ind);
            fascins2 = dice_babble_nogo_fascins_data(:,:,time_ind);
            fascins3 = color_wm_babble_nogo_fascins_data(:,:,time_ind);
            fascins4 = tones_wm_babble_nogo_fascins_data(:,:,time_ind);  
        else
            area_ind = BabbleNoGo_ind;      
            fasc_ind = BabbleInittoNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = TNoisetoBNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Color_WMtoBNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = Tones_WMtoBNoGo_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins;  
        end;
        set(tot_babble_nogo_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4);   
    end; 
    
 %  116 Inputs -> Plan fascicle summed net input
%  117 Babble -> Plan fascicle summed net input
%  118 Bias -> Plan fascicle summed net input
%  119 Total Plan fascicle summed net input    

    % Draw Inputs -> Plan fascicle summed net input sums.
    plot_id = 116;
    if (subplot_inds(plot_id,3) > 0)
        axes(inputs_plan_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = vispres_plan_fascins_data(:,:,time_ind);     
            fascins2 = color_wm_plan_fascins_data(:,:,time_ind);
            fascins3 = tones_wm_plan_fascins_data(:,:,time_ind); 
        else
            area_ind = Plan_ind;
            fasc_ind = VisStimtoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = Color_WMtoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;  
            fasc_ind = Tones_WMtoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;  
        end;
        set(inputs_plan_fascins_im,'CData',fascins1+fascins2+fascins3);   
    end; 

    % Draw Babble -> Plan fascicle summed net input sums.
    plot_id = 117;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_plan_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = babble_plan_fascins_data(:,:,time_ind);
        else
            area_ind = Plan_ind;
            fasc_ind = BabbletoPlan_ind; 
            fetchps_area_fascin_iter;
        end;
        set(babble_plan_fascins_im,'CData',fascins);   
    end;     
    
    % Draw Bias -> Plan fascicle summed net input sums.
    plot_id = 118;
    if (subplot_inds(plot_id,3) > 0)
        axes(bias_plan_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = bias_plan_fascins_data(:,:,time_ind);
        else
            area_ind = Plan_ind;
            fasc_ind = PlanBias_ind; 
            fetchps_area_fascin_iter;
        end;
        set(bias_plan_fascins_im,'CData',fascins);   
    end;     
    
    % Draw Total Plan fascicle summed net input sums.
    plot_id = 119;
    if (subplot_inds(plot_id,3) > 0)
        axes(total_plan_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = vispres_plan_fascins_data(:,:,time_ind);
            fascins2 = color_wm_plan_fascins_data(:,:,time_ind);
            fascins3 = tones_wm_plan_fascins_data(:,:,time_ind);
            fascins4 = babble_plan_fascins_data(:,:,time_ind); 
            fascins5 = bias_plan_fascins_data(:,:,time_ind);             
        else
            area_ind = Plan_ind;      
            fasc_ind = VisStimtoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;  
            fasc_ind = Color_WMtoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;     
            fasc_ind = Tones_WMtoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;
            fasc_ind = BabbletoPlan_ind; 
            fetchps_area_fascin_iter;
            fascins4 = fascins;  
            fasc_ind = PlanBias_ind; 
            fetchps_area_fascin_iter;
            fascins5 = fascins;              
        end;
        set(total_plan_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3 + fascins4 + fascins5);   
    end;    
    
    % Draw Plan -> Nod Request fascicle summed net input sums.
    plot_id = 120;
    if (subplot_inds(plot_id,3) > 0)
        axes(plan_nod_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = plan_nod_req_fascins_data(:,:,time_ind); 
        else
            area_ind = NodReqE_ind;
            fasc_ind = PlantoNodReqE_ind; 
            fetchps_area_fascin_iter;
        end;
        set(plan_nod_req_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Babble -> Nod Request fascicle summed net input sums.
    plot_id = 121;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_nod_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = babble_nod_req_fascins_data(:,:,time_ind); 
        else
            area_ind = NodReqE_ind;
            fasc_ind = BabbletoNodReqE_ind; 
            fetchps_area_fascin_iter;
        end;
        set(babble_nod_req_fascins_im,'CData',fascins);   
    end;  
  
    % Draw Bias -> Nod Request fascicle summed net input sums.
    plot_id = 122;
    if (subplot_inds(plot_id,3) > 0)
        axes(bias_nod_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = bias_nod_req_fascins_data(:,:,time_ind); 
        else
            area_ind = NodReqE_ind;
            fasc_ind = NodReqBias_ind; 
            fetchps_area_fascin_iter;
        end;
        set(bias_nod_req_fascins_im,'CData',fascins);   
    end;     
    
    % Draw Total Nod Request fascicle summed net input sums.
    plot_id = 123;
    if (subplot_inds(plot_id,3) > 0)
        axes(total_nod_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = plan_nod_req_fascins_data(:,:,time_ind);
            fascins2 = babble_nod_req_fascins_data(:,:,time_ind);
            fascins3 = bias_nod_req_fascins_data(:,:,time_ind);            
        else
            area_ind = NodReqE_ind;        
            fasc_ind = PlantoNodReqE_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;     
            fasc_ind = BabbletoNodReqE_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;       
            fasc_ind = NodReqBias_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;            
        end;
        set(total_nod_req_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3);   
    end;   
    
    % Draw Plan -> Shake Request fascicle summed net input sums.
    plot_id = 124;
    if (subplot_inds(plot_id,3) > 0)
        axes(plan_shake_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = plan_shake_req_fascins_data(:,:,time_ind); 
        else
            area_ind = ShakeReqE_ind;
            fasc_ind = PlantoShakeReqE_ind; 
            fetchps_area_fascin_iter;
        end;
        set(plan_shake_req_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Babble -> Shake Request fascicle summed net input sums.
    plot_id = 125;
    if (subplot_inds(plot_id,3) > 0)
        axes(babble_shake_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = babble_shake_req_fascins_data(:,:,time_ind); 
        else
            area_ind = ShakeReqE_ind;
            fasc_ind = BabbletoShakeReqE_ind; 
            fetchps_area_fascin_iter;
        end;
        set(babble_shake_req_fascins_im,'CData',fascins);   
    end;     
     
    % Draw Bias -> Shake Request fascicle summed net input sums.
    plot_id = 126;
    if (subplot_inds(plot_id,3) > 0)
        axes(bias_shake_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins = bias_shake_req_fascins_data(:,:,time_ind); 
        else
            area_ind = ShakeReqE_ind;
            fasc_ind = ShakeReqBias_ind; 
            fetchps_area_fascin_iter;
        end;
        set(bias_shake_req_fascins_im,'CData',fascins);   
    end; 
    
    % Draw Total Shake Request fascicle summed net input sums.
    plot_id = 127;
    if (subplot_inds(plot_id,3) > 0)
        axes(total_shake_req_fascins_axes);
        if (do_precalc_fascins == 1)
            fascins1 = plan_shake_req_fascins_data(:,:,time_ind);
            fascins2 = babble_shake_req_fascins_data(:,:,time_ind);
            fascins3 = bias_shake_req_fascins_data(:,:,time_ind);            
        else
            area_ind = ShakeReqE_ind;        
            fasc_ind = PlantoShakeReqE_ind; 
            fetchps_area_fascin_iter;
            fascins1 = fascins;     
            fasc_ind = BabbletoShakeReqE_ind; 
            fetchps_area_fascin_iter;
            fascins2 = fascins;       
            fasc_ind = ShakeReqBias_ind; 
            fetchps_area_fascin_iter;
            fascins3 = fascins;            
        end;
        set(total_shake_req_fascins_im,'CData',fascins1 + fascins2 + ... 
            fascins3);   
    end;     
    
end;