%
% fetchps_cell_wt_alliters.m
%
% Fetch the trace over the entire simulation of the strength of a
% particular weight in a particular fascicle.  Use after a simulation run.
% fasc_ind selects the fascicle.  x1_ind and y1_ind select which 
% cell in the source area is the source of our weight, and x2_ind and
% y2_ind select which cell in the target area is the target of our weight.
%
% Depends on: fasc_ind, x1_ind, y1_ind, x2_ind, y2_ind, NC, CA, CW, MOD, 
% modCW, Conn_fromto, Area_xy
%
% Last modification: 6/6/07


% Find the indices for the first and last connection of the desired fascicle.
first_conn_ind = 1;
for xx_fcwa = 1:fasc_ind - 1
    first_conn_ind = first_conn_ind + NC(xx_fcwa);
end;
last_conn_ind = first_conn_ind + NC(fasc_ind) - 1;

% Get the connection to and from addresses for the desired fascicle, and 
% subtract the unit offsets to get the relative connection addresses.
addr = double(CA(:,first_conn_ind:last_conn_ind));
addr(1,:) = addr(1,:) - unit_offset(Conn_fromto(fasc_ind,2));
addr(2,:) = addr(2,:) - unit_offset(Conn_fromto(fasc_ind,1));

% Get the area sizes for the input and output areas
in_x_sz = Area_xy(Conn_fromto(fasc_ind,1),1);
in_y_sz = Area_xy(Conn_fromto(fasc_ind,1),2);
out_x_sz = Area_xy(Conn_fromto(fasc_ind,2),1);
out_y_sz = Area_xy(Conn_fromto(fasc_ind,2),2);

% Find the index into CW for the desired weight.
source_ind = (x1_ind - 1) * in_y_sz + y1_ind;
target_ind = (x2_ind - 1) * out_y_sz + y2_ind;
wt_ind = 0;
for xx_fcwa = 1:size(addr,2)
    if ((addr(1,xx_fcwa) == target_ind) && (addr(2,xx_fcwa) == source_ind))
        wt_ind = xx_fcwa;
    end;
end;
if (wt_ind == 0)
    disp('Error: bad unit index');
    return;
else
    wt_ind = wt_ind + first_conn_ind - 1;
end;

% If the weight is modifiable, return the weights set in modCW.
if (MOD(CH(wt_ind)) == 1)
    wt_trace = modCW(find(mdc == wt_ind),:);
else
    wt_trace = ones(1,num_iters) * CW(wt_ind);
end; 