%
% phys_initA.m
% 
% Read the physiological parameters for the net from a file.
%
% Last modification: 7/27/07

% Clear all variables and close all windows.
clear all;
close all;

% Load the simulation run parameters.
load sim_run_params;

% Open the parameter file.
fid = fopen(phys_parm_fname, 'rt');

curr_CLT = 1;
curr_CHT = 1;

while 1
    % Read the next line.
    line = fgets(fid);
    
    % Only read stuff in if the line isn't a %-comment and isn't blank.
    if ((line(1) ~= '%') & (size(line,2) > 2) & (~isempty(line)))
        items = tokenize(line, ' ');
        Param_name = sscanf(items(1,:),'%s');
        if (size(items,1) > 1)
            params = str2double(items(2,:));
        end;

        if (strcmp(Param_name,'NumCellTypes'))
            CLT = params(1);
            thresh = zeros(1,CLT);
            gain = zeros(1,CLT);
            namp = zeros(1,CLT);
            outtimeconst = zeros(1,CLT);
            kWTA = zeros(1,CLT);
            pooled_kWTA = zeros(1,CLT);
            DA_out_mod = zeros(1,CLT);
            hi_DA_thresh = zeros(1,CLT);
            hi_DA_gain = zeros(1,CLT);
        elseif (strcmp(Param_name,'NumChanTypes'))
            CHT = params(1);
            VI = zeros(1,CHT);
            inhib = zeros(1,CHT);            
            MOD = zeros(1,CHT);
            eligib_duration = zeros(1,CHT);
            eligib_pre_thresh = zeros(1,CHT);
            eligib_post_thresh = zeros(1,CHT);
            DA_plastic_hi_thresh = zeros(1,CHT);
            DA_plastic_lo_thresh = zeros(1,CHT);
            DA_LTP_hi = zeros(1,CHT);
            LTP_learnrate = zeros(1,CHT);
            LTD_learnrate = zeros(1,CHT);
            maxwt = zeros(1,CHT);     
            maxtotwt = zeros(1,CHT);                 
        elseif (strcmp(Param_name,'Threshold'))
            thresh(curr_CLT) = params(1);
        elseif (strcmp(Param_name,'Gain'))
            gain(curr_CLT) = params(1);
        elseif (strcmp(Param_name,'NoiseAmp'))
            namp(curr_CLT) = params(1);
        elseif (strcmp(Param_name,'OutTimeConst'))
            outtimeconst(curr_CLT) = params(1);
        elseif (strcmp(Param_name,'kWTA'))
            kWTA(curr_CLT) = params(1);   
        elseif (strcmp(Param_name,'PooledkWTA'))
            pooled_kWTA(curr_CLT) = params(1);              
        elseif (strcmp(Param_name,'DAOutMod'))
            DA_out_mod(curr_CLT) = params(1);
        elseif (strcmp(Param_name,'HiDAThresh'))
            hi_DA_thresh(curr_CLT) = params(1);            
        elseif (strcmp(Param_name,'HiDAGain'))
            hi_DA_gain(curr_CLT) = params(1);            
        elseif (strcmp(Param_name,'VoltIndep'))
            VI(curr_CHT) = params(1); 
        elseif (strcmp(Param_name,'Inhibitory'))
            inhib(curr_CHT) = params(1);                      
        elseif (strcmp(Param_name,'Modifiable'))
            MOD(curr_CHT) = params(1);
        elseif (strcmp(Param_name,'EligDur'))
            eligib_duration(curr_CHT) = params(1);
        elseif (strcmp(Param_name,'EligPreThresh'))
            eligib_pre_thresh(curr_CHT) = params(1);            
        elseif (strcmp(Param_name,'EligPostThresh'))
            eligib_post_thresh(curr_CHT) = params(1);  
        elseif (strcmp(Param_name,'DAHiThresh'))
            DA_plastic_hi_thresh(curr_CHT) = params(1);              
        elseif (strcmp(Param_name,'DALoThresh'))
            DA_plastic_lo_thresh(curr_CHT) = params(1);  
        elseif (strcmp(Param_name,'DALTPHi'))
            DA_LTP_hi(curr_CHT) = params(1);              
        elseif (strcmp(Param_name,'LTPLearnRate'))
            LTP_learnrate(curr_CHT) = params(1);              
        elseif (strcmp(Param_name,'LTDLearnRate'))
            LTD_learnrate(curr_CHT) = params(1);             
        elseif (strcmp(Param_name,'MaxWeight'))
            maxwt(curr_CHT) = params(1);
        elseif (strcmp(Param_name,'MaxTotWeight'))
            maxtotwt(curr_CHT) = params(1);            
        elseif (strcmp(Param_name,'NEXTCELLTYPE'))
            curr_CLT = curr_CLT + 1;
        elseif (strcmp(Param_name,'NEXTCHANTYPE'))
            curr_CHT = curr_CHT + 1;
        end;
        
    end; % if we have a valid line
    
    % Break out of the loop if we're at the end of the file.
    if feof(fid)
        break;
    end;
        
end; % while loop

% Close the parameter file.
fclose(fid);

% Save the physiological parameters to a MAT file.
save(phys_fname,'thresh','gain','namp','outtimeconst','kWTA', ...
    'pooled_kWTA','DA_out_mod','hi_DA_thresh','hi_DA_gain','VI', ...
    'inhib','MOD','eligib_duration','eligib_pre_thresh', ...
    'eligib_post_thresh','DA_plastic_hi_thresh','DA_plastic_lo_thresh', ...
    'DA_LTP_hi','LTP_learnrate','LTD_learnrate','maxwt','maxtotwt');