%
% plot_wt_learning.m
%
% This script shows plots of variables over the simulation that are
% relevant to the learning of a particular weight.
%
% Last modification: 5/19/08


% Make sure we have all of the model indices.
get_cog_model_indices;

% Set the NoGo thalamic activity threshold for display.
NoGo_thal_elig_thresh = 0.25;  

%
% Set up user-selected initial variables.
%

% Set up the weight we want to track.
% fasc_ind = Color_WMtoRewCueE_ind;  % Color WM to Reward Cue
% fasc_ind = Color_WMtoBReq_ind;     % Color WM to Babble Request
fasc_ind = Color_WMtoPlan_ind;     % Color WM to Plan
% Blue WM -> Plan settings
x1_ind = 1;
y1_ind = 3;
x2_ind = 2;
y2_ind = 4;
% Red WM -> Plan settings
% x1_ind = 1;
% y1_ind = 1;
% x2_ind = 6;
% y2_ind = 1;
% fasc_ind = Color_WMtoNGo_ind;      % Color WM to Nod Go
% fasc_ind = Color_WMtoNNoGo_ind;    % Color WM to Nod NoGo
% fasc_ind = Color_WMtoSGo_ind;      % Color WM to Shake Go
% fasc_ind = Color_WMtoSNoGo_ind;    % Color WM to Shake NoGo
% fasc_ind = Color_WMtoBGo_ind;      % Color WM to Babble Go
% fasc_ind = Color_WMtoBNoGo_ind;    % Color WM to Babble NoGo
% Blue WM -> Nod/Shake/Babble Go/NoGo settings
% x1_ind = 1;
% y1_ind = 3;
% x2_ind = 2;
% y2_ind = 1;
% fasc_ind = Tones_WMtoRewCueE_ind;  % C Tone WM to Reward Cue
% fasc_ind = Tones_WMtoBReq_ind;     % C Tone WM to Babble Request
% fasc_ind = Tones_WMtoBGo_ind;      % C Tone WM to Babble Go
% fasc_ind = Tones_WMtoBNoGo_ind;    % C Tone WM to Babble NoGo
% fasc_ind = Tones_WMtoPlan_ind;     % C Tone WM to Plan
% fasc_ind = Tones_WMtoNGo_ind;      % C Tone WM to Nod Go
% fasc_ind = Tones_WMtoNNoGo_ind;    % C Tone WM to Nod NoGo
% fasc_ind = Tones_WMtoSGo_ind;      % C Tone WM to Shake Go
% fasc_ind = Tones_WMtoSNoGo_ind;    % C Tone WM to Shake NoGo
% x1_ind = 1;
% y1_ind = 1;
% x2_ind = 5;
% y2_ind = 5;
% fasc_ind = PlantoNodReqE_ind;      % Plan to Nod Request
% fasc_ind = PlantoShakeReqE_ind;    % Plan to Shake Request
% x1_ind = 5;
% y1_ind = 6;
% x2_ind = 1;
% y2_ind = 1;

% fasc_ind = Color_WMtoNNoGo_ind;
% fasc_ind = Color_WMtoSNoGo_ind;
% fasc_ind = Color_WMtoBNoGo_ind;
% fasc_ind = Color_WMtoBGo_ind;
% x1_ind = 1;
% y1_ind = 3;
% x2_ind = 4;
% y2_ind = 3;

% Set up range of iterations to plot.
min_iter = 1;
max_iter = num_iters;
% min_iter = 620;
% max_iter = 300;

% Initialize title of plot.
plot_title = 'Weight Learning';

% Initialize labels for plots (in order of plot IDs).
plot_labels = ...
    str2mat( ...
    'default', ...
    'default', ...
    'default', ...
    'default', ...
    'default', ...  
    'default', ...      
    'InitAff', ...
    'NSGoDA', ... 
    'NSNGoDA', ...  
    'BGoDA',   ... 
    'BNoGoDA', ...
    'PlanDA',  ...
    'ReqDA'    ...
    );

% Set up (in order of plot IDs) y axis settings.  Each row is a plot = 
% [ custom? min_y max_y min_y_tick max_y_tick ]
y_axis_layout = [ ...
      0  -1  11   0  10; ...
      0  -1  11   0  10; ...
      0  -1  11   0  10; ...
      0  -1  11   0  10; ...  
      0  -1  11   0  10; ...        
      0  -1  11   0  10; ...  
      1   0  1.0  0  1.0; ... 
      0  -1  11   0  10;  ... 
      0  -1  11   0  10;  ...  
      0  -1  11   0  10;  ...
      0  -1  11   0  10;  ...  
      0  -1  11   0  10;  ...          
      0  -1  11   0  10  ...       
      ];

num_avail_plots = size(y_axis_layout,1);
  
% Lay out the display.
% ID#  What it plots
% -------------------
%   1  Pre-synaptic activation for weight
%   2  Post-synaptic activation for weight
%   3  Eligibility trace for weight
%   4  Dopamine unit firing activation
%   5  Reward unit activation
%   6  Weight value
%   7  Nod GoE -> Input fascicle activity
%   8  DA Nod/Shake Go unit effects 
%   9  DA Nod/Shake NoGo unit effects
%  10  DA Babble Go unit effects
%  11  DA Babble NoGo unit effects
%  12  DA plan unit effects
%  13  DA request unit effects
%  xx  Work in progress...

% This is the ordering in which the plots are to be shown...
if ((fasc_ind == Color_WMtoNGo_ind) || ...
    (fasc_ind == Color_WMtoSGo_ind) || ...
    (fasc_ind == Tones_WMtoNGo_ind) || ...      
    (fasc_ind == Tones_WMtoSGo_ind))
    disp_plot_map = [1 2 3 8 4 5 6]; 
elseif ((fasc_ind == Color_WMtoNNoGo_ind) || ...
    (fasc_ind == Color_WMtoSNoGo_ind) || ...
    (fasc_ind == Tones_WMtoNNoGo_ind) || ...      
    (fasc_ind == Tones_WMtoSNoGo_ind))
    disp_plot_map = [1 2 7 3 9 4 5 6];  
elseif ((fasc_ind == Color_WMtoBGo_ind) || ...     
    (fasc_ind == Tones_WMtoBGo_ind))
    disp_plot_map = [1 2 3 10 4 5 6]; 
elseif ((fasc_ind == Color_WMtoBNoGo_ind) || ...   
    (fasc_ind == Tones_WMtoBNoGo_ind))
    disp_plot_map = [1 2 7 3 11 4 5 6];      
elseif ((fasc_ind == Color_WMtoPlan_ind) || ...   
    (fasc_ind == Tones_WMtoPlan_ind))
    disp_plot_map = [1 2 3 12 4 5 6];    
elseif ((fasc_ind == PlantoNodReqE_ind) || ...   
    (fasc_ind == PlantoShakeReqE_ind))
    disp_plot_map = [1 2 3 13 4 5 6];    
else
    disp_plot_map = [1 2 3 4 5 6];    
end;

%
% Color definitions.
%
col_red =    [1    0   0];
col_orange = [1    0.5 0];
col_yellow = [1    1   0];
col_green =  [0    1   0];
col_blue =   [0    0   1];
col_indigo = [0.5  0   1];
col_violet = [1    0   1];
col_black =  [0    0   0];
col_white =  [1    1   1];

%
% Load some of the data to be plotted.
%
            
% Fetch the data for later plotting and to get the weight index to CW.
fetchps_cell_wt_alliters;

% Calculate indices for source and target units in weight.
source_addr = double(CA(2,wt_ind));
target_addr = double(CA(1,wt_ind));        
for (ii = 1:Num_areas-1)
    if ((unit_offset(ii) < source_addr) && ...
        (source_addr <= unit_offset(ii + 1)))
        wc_source_area = ii;
    end;
    if ((unit_offset(ii) < target_addr) && ...
        (target_addr <= unit_offset(ii + 1)))
        wc_targ_area = ii;
    end;            
end;
if (source_addr > unit_offset(Num_areas))
    wc_source_area = Num_areas;
end;
if (target_addr > unit_offset(Num_areas))
    wc_targ_area = Num_areas;
end;
in_x_sz = Area_xy(wc_source_area,1);
in_y_sz = Area_xy(wc_source_area,2);
out_x_sz = Area_xy(wc_targ_area,1);
out_y_sz = Area_xy(wc_targ_area,2);
source_unit_ind = source_addr - unit_offset(wc_source_area);
wc_source_unit_x = floor((source_unit_ind - 1) / in_y_sz) + 1;
wc_source_unit_y = mod(source_unit_ind - 1,in_y_sz) + 1;
targ_unit_ind = target_addr - unit_offset(wc_targ_area);
wc_targ_unit_x = floor((targ_unit_ind - 1) / out_y_sz) + 1;
wc_targ_unit_y = mod(targ_unit_ind - 1,out_y_sz) + 1; 

% 
% Set up figure for plotting.
%

% Set up the figure window.
small_window = 0;
if (small_window == 1)
    l_fig_pos = 0.01;
    b_fig_pos = 0.05;
    fig_w = 0.7;
    fig_h = 0.6;
else
    l_fig_pos = 0.01;
    b_fig_pos = 0.05;
    fig_w = 0.9;
    fig_h = 0.85;
end;
% fh = figure(1);
fh = figure;
set(fh,'Units','normalized');
set(fh,'Position',[l_fig_pos b_fig_pos fig_w fig_h]);
colormap(gray);

% Lay out the subplots.
num_plots = size(disp_plot_map,2);
subplot_inds = zeros(num_avail_plots,3);
for ii = 1:num_avail_plots
    x = find(disp_plot_map == ii);
    subplot_inds(ii,1) = num_plots;
    subplot_inds(ii,2) = 1;
    if (isempty(x))
        subplot_inds(ii,3) = 0;
    else
        subplot_inds(ii,3) = x;
    end;
end;

%
% Plot the pre-synaptic activity.
%
plot_id = 1;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch the data.
    area_ind = wc_source_area;
    unit_x = wc_source_unit_x;
    unit_y = wc_source_unit_y;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;       
        the_plot(ii) = activs(unit_y,unit_x);
    end;    
    
    % Plot the data.
    area(the_plot);
    
    % Plot the threshold for the eligibility pre-synaptic activation.
    hold on;
    the_plot = eligib_pre_thresh(CH(wt_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(plot_labels(plot_id,:), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(unit_x),',', ...
            num2str(unit_y),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the post-synaptic activity.
%
plot_id = 2;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch the data.
    area_ind = wc_targ_area;
    unit_x = wc_targ_unit_x;
    unit_y = wc_targ_unit_y;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;       
        the_plot(ii) = activs(unit_y,unit_x);
    end;    
    
    % Plot the data.
    area(the_plot);
    
    % Plot the threshold for the eligibility post-synaptic activation.
    hold on;
    the_plot = eligib_post_thresh(CH(wt_ind)) * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(plot_labels(plot_id,:), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(unit_x),',', ...
            num2str(unit_y),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the eligibility trace value.
%
plot_id = 3;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));  
    
    % Plot the data.
    area(elig_trace(find(mdc == wt_ind),:));
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(plot_labels(plot_id,:), 'default'))
%         ystr = strcat(Area_name(area_ind,:),' (', num2str(unit_x),',', ...
%             num2str(unit_y),')');
        ystr = 'Elig. Trace';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the dopamine cell activity.
%
plot_id = 4;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch the data.
    area_ind = DASignal_ind;
    unit_x = 1;
    unit_y = 1;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;       
        the_plot(ii) = activs(unit_y,unit_x);
    end;    
    
    % Plot the data.
    area(the_plot);
    
    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(plot_labels(plot_id,:), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(unit_x),',', ...
            num2str(unit_y),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the reward unit activity.
%
plot_id = 5;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch the data.
    area_ind = RewardIn_ind;
    unit_x = 1;
    unit_y = 1;
    for ii = 1:num_iters
        time_ind = ii;
        fetchps_area_activs_iter;       
        the_plot(ii) = activs(unit_y,unit_x);
    end;    
    
    % Plot the data.
    area(the_plot);
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(plot_labels(plot_id,:), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(unit_x),',', ...
            num2str(unit_y),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the weight value.
%
plot_id = 6;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
      
    % Plot the data.
    area(wt_trace);
    
    % Plot the high threshold for the weight.
    hold on;
    the_plot = maxwt(CH(wt_ind)) * ones(1,num_iters);
    plot(the_plot,'b');
    hold off;
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(plot_labels(plot_id,:), 'default'))
%         ystr = strcat(Area_name(area_ind,:),' (', num2str(unit_x),',', ...
%             num2str(unit_y),')');
        ystr = 'Weight';
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the Nod GoE -> Init fascicle summed net input activity.
%
plot_id = 7;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
        
    % Fetch and plot the data.
    area_ind = wc_targ_area;
    x_ind = x2_ind;
    y_ind = y2_ind;
    if ((fasc_ind == Color_WMtoNNoGo_ind) || ...
        (fasc_ind == Tones_WMtoNNoGo_ind))
        fasc_ind = NodInittoNoGo_ind;
    elseif ((fasc_ind == Color_WMtoSNoGo_ind) || ...
        (fasc_ind == Tones_WMtoSNoGo_ind))
        fasc_ind = ShakeInittoNoGo_ind;        
    else
        fasc_ind = BabbleInittoNoGo_ind;
    end;
    fetchps_unit_fascin_alliters;
    area(fascin_trace); 

    % Plot the threshold for the eligibility enabling effect of Init 
    % activity.
    hold on;
    the_plot = NoGo_thal_elig_thresh * ones(1,num_iters);
    plot(the_plot,'g');
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Nod/Shake Go unit effects.
%
plot_id = 8;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 3;
    fetchps_unit_activ_alliters;
    area(activ_trace); 

    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Nod/Shake NoGo unit effects.
%
plot_id = 9;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 4;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  
      
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Babble Go unit effects.
%
plot_id = 10;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 5;
    fetchps_unit_activ_alliters;
    area(activ_trace); 
    
    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  

    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA Babble NoGo unit effects.
%
plot_id = 11;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 6;
    fetchps_unit_activ_alliters;
    area(activ_trace); 

    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA plan unit effects.
%
plot_id = 12;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 1;
    fetchps_unit_activ_alliters;
    area(activ_trace); 

    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

%
% Plot the DA request unit effects.
%
plot_id = 13;
if (subplot_inds(plot_id,3) > 0)
    % Set up the subplot.
    subplot(subplot_inds(plot_id,1), subplot_inds(plot_id,2), ...
        subplot_inds(plot_id,3));
    
    % Fetch and plot the data.
    area_ind = DAEffects_ind;
    x_ind = 1;
    y_ind = 2;
    fetchps_unit_activ_alliters;
    area(activ_trace); 

    % Plot the high threshold for the dopamine activity.
    hold on;
    the_plot = DA_plastic_hi_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'g');
    else
        plot(the_plot,'r');        
    end;
    
    % Plot the low threshold for the dopamine activity.   
    the_plot = DA_plastic_lo_thresh(CH(wt_ind)) * ones(1,num_iters);
    if (DA_LTP_hi(CH(wt_ind)) == 1)
        plot(the_plot,'r');
    else
        plot(the_plot,'g');        
    end;
    hold off;  
    
    % Set up axes.
    if (y_axis_layout(plot_id,1) == 0)
        min_y_axis = -0.1;
        max_y_axis = 1.1; 
        min_y_tick = 0;
        max_y_tick = 1;
    else
        min_y_axis = y_axis_layout(plot_id,2);
        max_y_axis = y_axis_layout(plot_id,3); 
        min_y_tick = y_axis_layout(plot_id,4);
        max_y_tick = y_axis_layout(plot_id,5);           
    end;   
    ylab_shift = (min_y_axis + max_y_axis) / 2;
    axis([min_iter max_iter min_y_axis max_y_axis]);
    set(gca,'YTick',[min_y_tick max_y_tick]);
    set(gca,'YTickLabel',[min_y_tick max_y_tick],'FontSize',8);  
    
    % Set up axis label.
    xlab_shift = (max_iter - min_iter) / 60;    
    if (strcmp(deblank(plot_labels(plot_id,:)), 'default'))
        ystr = strcat(Area_name(area_ind,:),' (', num2str(x_ind),',', ...
            num2str(y_ind),')');
    else
        ystr = plot_labels(plot_id,:);
    end;    
    text(min_iter-xlab_shift,ylab_shift,ystr,'HorizontalAlignment','right');      
end;

% Show the title in the first subplot.
subplot(num_plots,1,1);
title(plot_title);

% Null out the X tick labels for all but the last subplot.
for ii = 1:(num_plots - 1);
    subplot(num_plots,1,ii);
    set(gca,'XTickLabel',[]);
end;

% Show the iterations in the last subplot.
subplot(num_plots,1,num_plots);
xlabel('Iterations (Increments of 100 ms)');