%
% rule_based_brain.m
%
% Run the brain according to rule-based procedures.
%
% Last modification: 8/3/06

% Brain inputs we have to work with...
% color_map(1)        % Red unit
% color_map(2)        % Green unit
% color_map(3)        % Blue unit
% color_map(4)        % Yellow unit
% tones_on(1-12)      % Tones C through B
% reward_on = 0;      % is there currently a reward?
% track_execute = 0;  % is the Track behavior on?
% nod_execute = 0;    % is the Nod behavior on?
% shake_execute = 0;  % is the Shake behavior on?

% Working memory available to the rule-based brain...
% last_seen_color     % what was the last color seen?
% last_heard_tone     % what was the tone we last heard?

% Set rule-based reaction types.
reaction_do_nothing = 0;
reaction_blue_accept = 1;
reaction_red_accept = 2;
reaction_c_accept = 3;
reaction_eflat_accept = 4;
reaction_combo_taskset = 5;

% Set the rule-based brain parameters.
% active_reaction = reaction_blue_accept;
% active_reaction = reaction_combo_taskset;

% If we're on the first simulation iteration, initialize variables.
if (iter == 1)
    last_seen_color = color_black;
    last_heard_tone = tone_none;
end;

% Exit if we're to do nothing.
if (active_reaction == reaction_do_nothing)
    return;
end;

% Flag immediate detections of colors or (any) tone, updating working
% memory for the last seen color and last heard tone.
red_detected = (color_map(1) > 0.3);
green_detected = (color_map(2) > 0.3);
blue_detected = (color_map(3) > 0.3);
yellow_detected = (color_map(4) > 0.5);
violet_detected = (color_map(1) > 0.3) && (color_map(3) > 0.2);
tone_detected = 0;
for xx = 1:12
    if (tones_on(xx) == 1)
        tone_detected = 1;
        last_heard_tone = xx;
    end;
end;
if (red_detected == 1)
    last_seen_color = color_red;
elseif (green_detected == 1)  
    last_seen_color = color_green;    
elseif (blue_detected == 1)  
    last_seen_color = color_blue;    
elseif (yellow_detected == 1)  
    last_seen_color = color_yellow;    
elseif (violet_detected == 1)  
    last_seen_color = color_violet;
end;

% Do blue accept reaction.
if (active_reaction == reaction_blue_accept)
    if ((blue_detected == 1) && (violet_detected == 0))
        if (nod_execute == 0)
            nod_execute = 1;
        end;        
    elseif ((red_detected == 1) || (green_detected == 1) || ...
            (yellow_detected == 1) || (violet_detected == 1))
        if (shake_execute == 0)
            shake_execute = 1;
        end;
    end;
end;

% Do red accept reaction.
if (active_reaction == reaction_red_accept)
    if ((red_detected == 1) && (violet_detected == 0))
        if (nod_execute == 0)
            nod_execute = 1;
        end;
    elseif ((blue_detected == 1) || (green_detected == 1) || ...
            (yellow_detected == 1) || (violet_detected == 1)) 
        if (shake_execute == 0)
            shake_execute = 1;
        end;
    end;
end;

% Do C tone accept reaction.
if (active_reaction == reaction_c_accept)
    if ((tones_on(tone_c) == 1) && (nod_execute == 0))
        nod_execute = 1;
    elseif ((tone_detected == 1) && (shake_execute == 0))
        shake_execute = 1;
    end;
end;

% Do E-Flat tone accept reaction.
if (active_reaction == reaction_eflat_accept)
    if ((tones_on(tone_eflat) == 1) && (nod_execute == 0))
        nod_execute = 1;
    elseif ((tone_detected == 1) && (shake_execute == 0))
        shake_execute = 1;
    end;
end;

% Do combo taskset reaction.
if (active_reaction == reaction_combo_taskset)
    if (last_heard_tone == tone_c)
        if ((blue_detected == 1) && (violet_detected == 0))
            if (nod_execute == 0)
                nod_execute = 1;
            end;        
        elseif ((red_detected == 1) || (green_detected == 1) || ...
                (yellow_detected == 1) || (violet_detected == 1))
            if (shake_execute == 0)
                shake_execute = 1;
            end;
        end;
    elseif (last_heard_tone == tone_eflat)
        if ((red_detected == 1) && (violet_detected == 0))
            if (nod_execute == 0)
                nod_execute = 1;
            end;
        elseif ((blue_detected == 1) || (green_detected == 1) || ...
                (yellow_detected == 1) || (violet_detected == 1)) 
            if (shake_execute == 0)
                shake_execute = 1;
            end;
        end;
    end;
end;