% This script runs a network simulation.
% Last modification: 7/24/02
% Useful stuff here:
% * Code for various learning algorithms

% Close all figures and clear all variables.
close all;
clear all;

% 
% Initialize various simulation parameters.
%

% Set simulation control variables.
iter_ms = 5;            % number of milliseconds / iteration
dynamic_sim = 1;        % do a dynamic simulation?
dynam_speed = 50;       % number of milliseconds / shift of stimulus
warmup_time = 20;       % number of milliseconds in "warmup" phase of net
T = (warmup_time + 1 * (9 * dynam_speed)) / iter_ms;  % number of iterations
T = 3 * 540;
%T = 540;

% Learning constants for Tagamets/Horwitz learning algorithm
% d = 0.005;          % learning rate
% tot_wt = 0.72;      % total afferent weight
% pre_thr = 0.7;      % presynaptic threshold
% post_thr = 0.5;     % postsynaptic threshold

x_shft_pix = 4;
y_shft_pix = 4;

load_trained_wts = 0;   % load trained weights from previous simulation?
learning_on = 0;        % turn on learning?

init_unit_noise = 0.01;

monitor_interval = 100;  % how often to tell us how far we are along (0 turns off)
snapshot_interval = 0; % how often to save snapshots of activations and weight values (0 turns offs)
plot_net_activ = 1;
plot_learn_wts = 0;
plot_cw_x = 2;
plot_cw_y = 1;

sim_phase = 0;
phase_clock = 0;
move_clock = 0;
change_stim = 1;
dyn_stim_sel = 0;

%
% Load the simulation data.
%

% Load filters.
load V1_filts;

% Load and normalize the desired image.
load imageC1;   % this loads shift max's and min's too
I = I./max(max(I));
I = I';  % translate to get image oriented correctly.
I = conv2(I,blur,'same');
%I = sigm(3.5,10,I);
I = I./(max(max(I)));
stimI = I;  % The stimulus is this image if we're not doing a dynamic simulation

% If we're doing a dynamic simulation, load all stimuli and their shift parameters.
if (dynamic_sim == 1)
    % Load a blank stimulus.
    load imageNIL;   % this loads shift max's and min's too
    I = I./max(max(I));
    I = I';  % translate to get image oriented correctly.
    I = conv2(I,blur,'same');
    %I = sigm(3.5,10,I);
    I0 = I./(max(max(I)));
    I0 = I0./100;
    x_shft_min0 = x_shft_min;
    x_shft_max0 = x_shft_max;
    y_shft_min0 = y_shft_min;
    y_shft_max0 = y_shft_max;
    
    % Load the cross stimulus.
    load imageC1;   % this loads shift max's and min's too
    I = I./max(max(I));
    I = I';  % translate to get image oriented correctly.
    I = conv2(I,blur,'same');
    %I = sigm(3.5,10,I);
    I1 = I./(max(max(I)));
    x_shft_min1 = x_shft_min;
    x_shft_max1 = x_shft_max;
    y_shft_min1 = y_shft_min;
    y_shft_max1 = y_shft_max;
   
    % Load the T stimulus.
    load imageT1;   % this loads shift max's and min's too
    I = I./max(max(I));
    I = I';  % translate to get image oriented correctly.
    I = conv2(I,blur,'same');
    %I = sigm(3.5,10,I);
    I2 = I./(max(max(I)));
    x_shft_min2 = x_shft_min;
    x_shft_max2 = x_shft_max;
    y_shft_min2 = y_shft_min;
    y_shft_max2 = y_shft_max;
    
    % Load the L stimulus.
    load imageL1;   % this loads shift max's and min's too
    I = I./max(max(I));
    I = I';  % translate to get image oriented correctly.
    I = conv2(I,blur,'same');
    %I = sigm(3.5,10,I);
    I3 = I./(max(max(I)));
    x_shft_min3 = x_shft_min;
    x_shft_max3 = x_shft_max;
    y_shft_min3 = y_shft_min;
    y_shft_max3 = y_shft_max;
end;
    
% Load model parameters (connectivity and cell/channel-types).
if (load_trained_wts == 1)
    load modl_parm_tr;
else
    load modl_parm_1;
end;

% Load physiological parameters (cells and channels).
load phys_parm_2;

%
% Prepare the learning algorithm.
%

% Find the indices for the modifiable (i.e., learning) connections.
[a mdc] = find(MOD(CH));  

if ((~isempty(mdc)) & (learning_on == 1))
	% Find the indices for the modifiable connection fascicle indices.
	[a mdf] = find(MOD(Chan_type));
	
	% Get the list (with replications removed) of all indices of units containing
	% modifiable input weights.
	mdu = unique(CA(1,mdc));
	
	% Set up data structure for allowing summation of afferent connection weights
	% for modifiable units.
	conns_to_sum = [];
	conn_count = 1;
	for ii = 1:size(mdu,2)
        new_conns = intersect(mdc,find(CA(1,:) == mdu(ii)));
        cts_first(ii) = conn_count;
        conn_count = conn_count + size(new_conns,2);
        cts_last(ii) = conn_count - 1;
        conns_to_sum = [conns_to_sum new_conns]; 
	end;

    % Get various constants used in computing FSpast
	krho1 = k(1,CH(mdc))./rho(1,CH(mdc));
	krho2 = k(2,CH(mdc))./rho(2,CH(mdc));
	rhotheta1 = rho(1,CH(mdc)).*theta(1,CH(mdc));
	rhotheta2 = rho(2,CH(mdc)).*theta(2,CH(mdc));
	rhox1 = rho(1,CH(mdc)).*xscale(CH(mdc));
	rhox2 = rho(2,CH(mdc)).*xscale(CH(mdc));
end;

% Initialize vectors for unit activity.
% NOTE: Spast and S are ordered so that activity is drawn column-wise from the areas.
Spast = init_unit_noise * rand(1,sum(NU));      % random uniform distribution 0 to 1 * noise factor

% Initialize output data arrays.
output = zeros(sum(NU),T);

% V1 parameters
V1_offset = 0.35;  % offset to V1 squashing
V1_gain = 50;      % gain to V1 squashing
V1_nfr = 0.01;     % noise fraction for V1 units

%
% Simulation
%

ctime = cputime;

% Do convolutions to get inputs to vertical and horizontal V1 units.
% (This gets used in the case where we're not running a dynamic simulation.)
V1_input_h = conv2(stimI,filt_h,'same');
V1_input_v = conv2(stimI,filt_v,'same');

% For each iteration...
for t=1:T
      
% Monitor progress.
if (mod(t,monitor_interval) == 0) disp(['Iteration ',num2str(t)]); end;

% Save snapshot if at appropriate interval.
if (mod(t,snapshot_interval) == 0)
    save(strcat('sshot',num2str(t)), 'CW', 'output', 'T');
end;

% If we're running a dynamic simulation...
if (dynamic_sim == 1)
       
    % Whichever script is called here needs to set the stimulus to I and also set the 
    % appropriate shifting variables, x_shift and y_shift.
    %dyn_stimpick2; 
    dyn_stimpick4;
    
    % Shift the stimulus to the appropriate place.
    stimI = matrot(x_shift,y_shift,I);
    
    % Do convolutions to get inputs to vertical and horizontal V1 units.
    V1_input_h = conv2(stimI,filt_h,'same');
    V1_input_v = conv2(stimI,filt_v,'same');  
end;

% Apply noise and squashing to V1 inputs.
V1_H = sigm(V1_offset,V1_gain,V1_input_h + V1_nfr.*randn(size(V1_input_h)));
V1_V = sigm(V1_offset,V1_gain,V1_input_v + V1_nfr.*randn(size(V1_input_v)));

% Now do the "Gestalt-like" self-connections
V1_H = conv2(V1_H,2.*gest_h2','same');
V1_V = conv2(V1_V,2.*gest_h2,'same');

% Apply noise and squashing to V1 inputs.
V1_H = sigm(V1_offset,V1_gain,V1_H + V1_nfr.*randn(size(V1_H)));
V1_V = sigm(V1_offset,V1_gain,V1_V + V1_nfr.*randn(size(V1_V)));

% Feed the horizontal V1 inputs into the first set of units of the network.
numV1_H = size(V1_H,1) * size(V1_H,2);
Spast(1:numV1_H) = V1_H;

% Feed the vertical V1 outputs into the second set of units of the network.
numV1_V = size(V1_V,1) * size(V1_V,2);
Spast((numV1_H + 1):(numV1_H + numV1_V)) = V1_V;

% First sum all the voltage-independent inputs; VI(CH) is the filter for vi-inputs.
Avi = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),VI(CH).*CW.*Spast(CA(2,:))),2)';

% Then sum all the voltage-dependent inputs.
% Avd = zeros(1,sum(NU)) + sum(sparse(double(CA(1,:)),1:sum(NC),~VI(CH) ...
%     .*sigm(0.1,10,Avi(CA(1,:))) ...
%     .*CW.*Spast(CA(2,:))),2)';

% Update unit activity.
%S = Spast + wcunitupdate(Spast,Avi+Avd,thresh(CT),gain(CT),namp(CT),growth(CT),decay(CT));
S = Spast + wcunitupdate(Spast,Avi,thresh(CT),gain(CT),namp(CT),growth(CT),decay(CT));

% Overwrite the new results for the V1 populations since these aren't supposed to be 
% changing except for noise.
S(1:numV1_H) = V1_H;
S((numV1_H + 1):(numV1_H + numV1_V)) = V1_V;

% Update connection weights if learning is on (and we're not in the warmup 
% phase of a dynamic simulation.
if ((learning_on == 1) & ~((dynamic_sim == 1) & (sim_phase == 0)))

% 
% Double hyperbolic tangent Hebbian learning algorithm
%
% Calculate FSpast using double hyperbolic tangent.
FSpast = zeros(1,sum(NU));

% wait a minute... Shouldn't FSpast range over 1:sum(NC)?  This there could be different 
% FSpast values depending upon the afferent connection type.  FSpast is postsynaptic, but 
% "dendritic" in nature.

% this is currently evaluated for each modifiable afferent (md), but need only
% be done once per postsynaptic cell (unique(md)); however, k, rho etc are 
% properties of connection types...
if (~isempty(mdc))
FSpast(1,CA(1,mdc)) = (krho1 - krho1.*tanh(rhox1.*Spast(CA(1,mdc))-rhotheta1))./krho2 + ...
    tanh(rhox2.*Spast(CA(1,mdc))-rhotheta2);
end;

% Added cheat...
% Find the unit with the maximum response and make this the winner.
% Set all of the FSpast values for each of the winner's connections to 1.0.
% winner = find(Spast(mdu) == max(Spast(mdu)));
% FSpast(1,CA(1,conns_to_sum(cts_first(winner):cts_last(winner)))) = 1.0;

% Finally update connections.
if (~isempty(mdc))
%CW(mdc) = CW(mdc) + learnrate(CH(mdc)).*Spast(CA(2,mdc)).*FSpast(CA(1,mdc));
CW(mdc) = CW(mdc) + learnrate(CH(mdc)).*(Spast(CA(2,mdc))>0.3).*Spast(CA(2,mdc)).*FSpast(CA(1,mdc));
%CW(mdc) = CW(mdc) + (CW(mdc) < 0.1) * learnrate(CH(mdc)).*(Spast(CA(2,mdc))>0.3).*Spast(CA(2,mdc)).*FSpast(CA(1,mdc));
end;

% %
% % Tagamets / Horwitz learning algorithm.
% %
% d = 0.005;
% tot_wt = 0.72;
% %tot_wt = 10.0;
% pre_thr = 0.7;
% post_thr = 0.5;
% 
% % Create the updated weight values.
% CWadj = CW;
% CWadj(mdc) = CW(mdc) + d .* Spast(CA(2,mdc)) .* Spast(CA(1,mdc)) .* (Spast(CA(2,mdc)) > pre_thr) ...
%     .* (Spast(CA(1,mdc)) > post_thr);
% 
% % Normalize the afferent weights.
% %CWnormsum = zeros(size(CWadj));
% for ii = 1:size(mdu,2)    
%     % Set the normalizing sums for each connection to the sum of the adjusted weights.
%     CWnormsum(conns_to_sum(cts_first(ii):cts_last(ii))) = sum(CWadj(conns_to_sum(cts_first(ii):cts_last(ii))));
% end;
% CW(mdc) = tot_wt .* CWadj(mdc) ./ CWnormsum(mdc);

% %
% % Kohonen-style learning algorithm
% %
% eta = 0.001;
% 
% % Initialize the weight updates to 0.
% FSpast = zeros(1,sum(NU));
% 
% if (~isempty(mdc))
% FSpast(1,CA(1,mdc)) = Spast(CA(1,mdc));
% end;
% 
% % Finally update connections.
% if (~isempty(mdc))
% % CW(mdc) = CW(mdc) + eta .* Spast(CA(2,mdc)) .* FSpast(CA(1,mdc));
% CW(mdc) = CW(mdc) + learnrate(CH(mdc)).*(Spast(CA(2,mdc))>0.3).*Spast(CA(2,mdc)).*FSpast(CA(1,mdc));
% end;

end; % if learning is on

% Save unit activities for later display.
output(:,t) = S';

% Remember the previous activations.
Spast = S;

% If we want, plot all of the layers after each time step.
if (plot_net_activ == 1)
	figure(1);
	colormap(gray);
	subplot(5,3,1)
	area_ind = 1; 
	disp_area_act;
	subplot(5,3,2)
	area_ind = 2; 
	disp_area_act;
	subplot(5,3,4)
	area_ind = 3; 
	disp_area_act;
	subplot(5,3,5)
	area_ind = 5; 
	disp_area_act;
	subplot(5,3,6)
	area_ind = 7; 
	disp_area_act;
 	subplot(5,3,7)
 	area_ind = 10; 
 	disp_area_act;
 	subplot(5,3,8)
 	area_ind = 12; 
 	disp_area_act;
 	subplot(5,3,9)
 	area_ind = 14; 
 	disp_area_act;
 	subplot(5,3,10)
 	area_ind = 16; 
 	disp_area_act;
  	subplot(5,3,11)
 	area_ind = 18; 
 	disp_area_act;
 	subplot(5,3,12)
 	area_ind = 20; 
 	disp_area_act;
 	subplot(5,3,13)
 	area_ind = 22; 
 	disp_area_act; 
	subplot(5,3,3)
	imagesc(stimI,[0 1]);
	axis square;
end;

if (plot_learn_wts == 1)
	figure(2);
	x_ind = plot_cw_x;
	y_ind = plot_cw_y;
	subplot(2,2,1)
	fasc_ind = 22;
	disp_cell_wts;
	subplot(2,2,2)
	fasc_ind = 23;
	disp_cell_wts;
	subplot(2,2,3)
	fasc_ind = 24;
	disp_cell_wts;
end;

% Add an additional pause if there's some plotting going on.
if ((plot_net_activ == 1) | (plot_learn_wts == 1))
    pause(0.1);
    %pause;
end;

end;   % end of main loop

cputime-ctime

save out1 output T

% Save new weights.
if ((~isempty(mdc)) & (learning_on == 1))    
    save modl_parm_tr Model_name Num_areas Num_conns Area_name Area_num Cell_type Area_xy Conn_name ...
       Conn_fromto Chan_type Conn_kind Conn_xy Conn_prob Weig_mean Weig_sigm Conn_scle CA CW CR CH CT NC NU unit_offset
end;

% figure(3);
% colormap(gray);
% area_ind = 11; 
% disp_area_act;

% figure(3);
% x_ind = 32;
% y_ind = 32;
% subplot(2,2,1)
% fasc_ind = 21;
% disp_cell_wts;
% subplot(2,2,2)
% fasc_ind = 22;
% disp_cell_wts;
% subplot(2,2,3)
% fasc_ind = 23;
% disp_cell_wts;
% subplot(2,2,4)
% fasc_ind = 24;
% disp_cell_wts;

 





