%
% tokenize.m
%
% Given a string and a delimiter, break the string up into tokens
% and return an array of these strings.
%
% Inputs:
%   line: the string for the whole line
%   delimiter: the character that delimits fields in the line (e.g. 
%      ' ' or ',')
%
% Last modification: 10/15/04

function [strs] = tokenize(line,delimiter)

    % Start with an empty token list.
    strs = '';
    num_toks = 0;
    
    % Remember the whole line.
    line_rem = line;
    rem_len = size(line_rem,2);
    
    % While we're not at the end of the line...
    while (rem_len > 0)
        % Find the first occurence of the delimiter (or the end of the line)
        ind = 1;
        while ((ind <= rem_len) & (line_rem(ind) ~= delimiter))
            ind = ind + 1;
        end;
        
        % If we found an occurence of the delimiter...
        % NOTE: if the first character on the line is a delimiter, this may barf!
        if (ind <= rem_len)
            % Grab the characters before the delimiter and make a new token from 
            % that.
            new_tok = line_rem(1:ind - 1);
            if (double(new_tok(size(new_tok,2))) == 10)  % if last character is 
                                                         % carriage-return
                new_tok = new_tok(1:size(new_tok,2) - 1);
            end;
            strs = str2mat(strs, new_tok);
            
            % Find the next character after the delimiter which isn't the delimiter.
            while ((line_rem(ind) == delimiter) & (ind <= rem_len))
                ind = ind + 1;
            end;
            
            % Chop the characters we've looked at off of the line.
            line_rem = line_rem(ind:rem_len);
            rem_len = size(line_rem,2);
 
        % Else, if we found the end of the line without hitting a delimiter...     
        else
            % Grab all the remaining characters.
            new_tok = line_rem(1:rem_len);
            if (double(new_tok(size(new_tok,2))) == 10)  % if last character is 
                                                         % carriage-return
                new_tok = new_tok(1:size(new_tok,2) - 1);      
            end;
            strs = str2mat(strs, new_tok);
            
            % Null out the rest of the string.
            rem_len = 0;         
        end;
        
        % Increment the token count.
        num_toks = num_toks + 1;
        
    end; % while
    
    % Strip out the null token element.
    strs = strs(2:num_toks+1,:);  
    

    